@@ -90,4 +90,4 @@ if tuple(int(x) for x in QtCore.__version__.split('.')[:3]) < (5, 12, 3):
 from napari._qt.qt_event_loop import get_app, get_qapp, gui_qt, quit_app, run
 from napari._qt.qt_main_window import Window
 
-__all__ = ['get_app', 'get_qapp', 'gui_qt', 'quit_app', 'run', 'Window']
+__all__ = ['Window', 'get_app', 'get_qapp', 'gui_qt', 'quit_app', 'run']
