@@ -1,5 +1,5 @@
 """Helper functions to create Qt objects from app-model objects."""
 
-from ._menus import build_qmodel_menu
+from napari._qt._qapp_model._menus import build_qmodel_menu
 
 __all__ = ['build_qmodel_menu']
