@@ -5,10 +5,26 @@ from unittest.mock import Mock
 import pytest
 from qtpy.QtWidgets import QAction, QShortcut
 
-from napari._qt.qt_event_loop import _ipython_has_eventloop, run, set_app_id
+from napari._qt.qt_event_loop import (
+    _ipython_has_eventloop,
+    get_app,
+    get_qapp,
+    run,
+    set_app_id,
+)
 
 
-@pytest.mark.skipif(os.name != 'Windows', reason='Windows specific')
+def test_qapp(qapp):
+    qapp = get_qapp()
+    with pytest.warns(
+        FutureWarning,
+        match='`QApplication` instance access through `get_app` is deprecated and will be removed in 0.6.0.\nPlease use `get_qapp` instead.\n',
+    ):
+        deprecated_qapp = get_app()
+    assert qapp == deprecated_qapp
+
+
+@pytest.mark.skipif(os.name != 'nt', reason='Windows specific')
 def test_windows_grouping_overwrite(qapp):
     import ctypes
 
@@ -26,8 +42,10 @@ def test_windows_grouping_overwrite(qapp):
     assert get_app_id() == 'test_text'
     set_app_id('custom_string')
     assert get_app_id() == 'custom_string'
-    set_app_id('')
-    assert get_app_id() == ''
+    set_app_id('')  # app id can't be an empty string
+    assert get_app_id() == 'custom_string'
+    set_app_id(' ')
+    assert get_app_id() == ' '
 
 
 def test_run_outside_ipython(make_napari_viewer, qapp, monkeypatch):
