@@ -1,14 +1,17 @@
 import sys
 
 import numpy.testing as npt
+import pyautogui
 import pytest
-from qtpy.QtCore import Qt
+from qtpy.QtCore import QPoint, Qt
+from qtpy.QtWidgets import QApplication
 
 from napari._pydantic_compat import BaseModel
 from napari._qt.dialogs.preferences_dialog import (
     PreferencesDialog,
     QMessageBox,
 )
+from napari._tests.utils import skip_local_focus, skip_on_mac_ci
 from napari._vendor.qt_json_builder.qt_jsonschema_form.widgets import (
     EnumSchemaWidget,
     FontSizeSchemaWidget,
@@ -280,3 +283,71 @@ def test_preferences_dialog_restore(qtbot, pref, monkeypatch):
             ).text()
         )
     ) == KeyBinding.from_str('Ctrl')
+
+
+@skip_local_focus
+@skip_on_mac_ci
+@pytest.mark.key_bindings
+@pytest.mark.parametrize(
+    'confirm_key',
+    ['enter', 'return', 'tab'],
+)
+def test_preferences_dialog_not_dismissed_by_keybind_confirm(
+    qtbot, pref, confirm_key
+):
+    """This test ensures that when confirming a keybinding change, the dialog is not dismissed.
+
+    Notes:
+        * Skipped on macOS CI due to accessibility permissions not being
+          settable on macOS GitHub Actions runners.
+        * For this test to pass locally, you need to give the Terminal/iTerm/VSCode
+          application accessibility permissions:
+              `System Settings > Privacy & Security > Accessibility`
+
+        See https://github.com/asweigart/pyautogui/issues/247 and
+        https://github.com/asweigart/pyautogui/issues/247#issuecomment-437668855
+    """
+    shortcut_widget = (
+        pref._stack.widget(3).widget().widget.widgets['shortcuts']
+    )
+    pref._stack.setCurrentIndex(3)
+    # ensure the dialog is showing
+    pref.show()
+    qtbot.waitExposed(pref)
+    assert pref.isVisible()
+
+    shortcut = shortcut_widget._table.item(
+        0, shortcut_widget._shortcut_col
+    ).text()
+    assert shortcut == 'U'
+
+    x = shortcut_widget._table.columnViewportPosition(
+        shortcut_widget._shortcut_col
+    )
+    y = shortcut_widget._table.rowViewportPosition(0)
+
+    item_pos = QPoint(x, y)
+    qtbot.mouseClick(
+        shortcut_widget._table.viewport(),
+        Qt.MouseButton.LeftButton,
+        pos=item_pos,
+    )
+    qtbot.mouseDClick(
+        shortcut_widget._table.viewport(),
+        Qt.MouseButton.LeftButton,
+        pos=item_pos,
+    )
+    qtbot.waitUntil(lambda: QApplication.focusWidget() is not None)
+    pyautogui.press('delete')
+    qtbot.wait(100)
+    pyautogui.press(confirm_key)
+    qtbot.wait(100)
+
+    # ensure the dialog is still open
+    assert pref.isVisible()
+
+    # verify that the keybind is changed
+    shortcut = shortcut_widget._table.item(
+        0, shortcut_widget._shortcut_col
+    ).text()
+    assert shortcut == ''
