@@ -1,7 +1,7 @@
 """
 A Class for generating QIcons from SVGs with arbitrary colors at runtime.
 """
-from functools import lru_cache
+
 from typing import Optional, Union
 
 from qtpy.QtCore import QByteArray, QPoint, QRect, QRectF, Qt
@@ -46,13 +46,12 @@ class QColoredSVGIcon(QIcon):
         color: Optional[str] = None,
         opacity: float = 1.0,
     ) -> None:
-        from ...resources import get_colorized_svg
+        from napari.resources import get_colorized_svg
 
         self._svg = path_or_xml
         colorized = get_colorized_svg(path_or_xml, color, opacity)
         super().__init__(SVGBufferIconEngine(colorized))
 
-    @lru_cache
     def colored(
         self,
         color: Optional[str] = None,
@@ -81,14 +80,13 @@ class QColoredSVGIcon(QIcon):
             A pre-colored QColoredSVGIcon (which may still be recolored)
         """
         if not color and theme:
-            from ...utils.theme import get_theme
+            from napari.utils.theme import get_theme
 
-            color = getattr(get_theme(theme, False), theme_key).as_hex()
+            color = getattr(get_theme(theme), theme_key).as_hex()
 
         return QColoredSVGIcon(self._svg, color, opacity)
 
     @staticmethod
-    @lru_cache
     def from_resources(
         icon_name: str,
     ) -> 'QColoredSVGIcon':
@@ -105,7 +103,7 @@ class QColoredSVGIcon(QIcon):
         QColoredSVGIcon
             A colorizeable QIcon
         """
-        from ...resources import get_icon_path
+        from napari.resources import get_icon_path
 
         path = get_icon_path(icon_name)
         return QColoredSVGIcon(path)
