@@ -233,6 +233,9 @@ class QtViewer(QSplitter):
         self.viewer._layer_slicer.events.ready.connect(self._on_slice_ready)
 
         self._on_active_change()
+        self.viewer.layers.events.inserted.connect(self._update_camera_depth)
+        self.viewer.layers.events.removed.connect(self._update_camera_depth)
+        self.viewer.dims.events.ndisplay.connect(self._update_camera_depth)
         self.viewer.layers.events.inserted.connect(self._update_welcome_screen)
         self.viewer.layers.events.removed.connect(self._update_welcome_screen)
         self.viewer.layers.selection.events.active.connect(
@@ -657,6 +660,41 @@ class QtViewer(QSplitter):
         layer = event.value
         self._add_layer(layer)
 
+    def _update_camera_depth(self):
+        """When the layer extents change, update the camera depth.
+
+        The camera depth is the difference between the near clipping plane
+        and the far clipping plane in a scene. If they are set too high
+        relative to the actual depth of a scene, precision issues can arise
+        in the depth of objects in the scene, with objects at the back
+        seeming to pop to the front.
+
+        See: https://github.com/napari/napari/issues/2138
+        """
+        if self.viewer.dims.ndisplay == 2:
+            # don't bother updating 3D camera if we're not using it
+            return
+        # otherwise, set depth to diameter of displayed dimensions
+        extent = self.viewer.layers.extent
+        # we add a step because the difference is *right* at the point
+        # coordinates, not accounting for voxel size:
+        # >>> viewer.add_image(np.random.random((2, 3, 4, 5)))
+        # >>> viewer.layers.extent
+        # Extent(
+        #     data=None,
+        #     world=array([[0., 0., 0., 0.],
+        #                  [1., 2., 3., 4.]]),
+        #     step=array([1., 1., 1., 1.]),
+        # )
+        extent_all = extent.world[1] - extent.world[0] + extent.step
+        extent_displayed = extent_all[list(self.viewer.dims.displayed)]
+        diameter = np.linalg.norm(extent_displayed)
+        # Use 128x the diameter to avoid aggressive near- and far-plane
+        # clipping in perspective projection, while still preserving enough
+        # bit depth in the depth buffer to avoid artifacts. See discussion at:
+        # https://github.com/napari/napari/pull/7529#issuecomment-2594203871
+        self.canvas.camera._3D_camera.depth_value = 128 * diameter
+
     def _add_layer(self, layer):
         """When a layer is added, set its parent and order.
 
