@@ -1,8 +1,11 @@
 import numpy as np
 import pytest
+from qtpy.QtCore import Qt
+from qtpy.QtWidgets import QApplication
 
 from napari._qt.widgets.qt_color_swatch import (
     TRANSPARENT,
+    QColorPopup,
     QColorSwatch,
     QColorSwatchEdit,
 )
@@ -17,9 +20,18 @@ def test_succesfull_create_qcolorswatchedit(qtbot, color, tooltip):
     test_color = color or TRANSPARENT
     test_tooltip = tooltip or 'click to set color'
 
+    # check widget creation and base values
     assert widget.color_swatch.toolTip() == test_tooltip
     np.testing.assert_array_equal(widget.color, test_color)
 
+    # check widget popup
+    qtbot.mouseRelease(widget.color_swatch, Qt.MouseButton.LeftButton)
+    color_popup = None
+    for widget in QApplication.topLevelWidgets():
+        if isinstance(widget, QColorPopup):
+            color_popup = widget
+    assert color_popup
+
 
 @pytest.mark.parametrize('color', [None, [1, 1, 1, 1]])
 @pytest.mark.parametrize('tooltip', [None, 'This is a test'])
@@ -30,5 +42,14 @@ def test_succesfull_create_qcolorswatch(qtbot, color, tooltip):
     test_color = color or TRANSPARENT
     test_tooltip = tooltip or 'click to set color'
 
+    # check widget creation and base values
     assert widget.toolTip() == test_tooltip
     np.testing.assert_array_equal(widget.color, test_color)
+
+    # check widget popup
+    qtbot.mouseRelease(widget, Qt.MouseButton.LeftButton)
+    color_popup = None
+    for widget in QApplication.topLevelWidgets():
+        if isinstance(widget, QColorPopup):
+            color_popup = widget
+    assert color_popup
