@@ -6,7 +6,10 @@ from qtpy.QtCore import Slot
 from qtpy.QtGui import QFont, QFontMetrics
 from qtpy.QtWidgets import QSizePolicy, QVBoxLayout, QWidget
 
-from napari._qt.widgets.qt_dims_slider import QtDimSliderWidget
+from napari._qt.widgets.qt_dims_slider import (
+    AnimationThread,
+    QtDimSliderWidget,
+)
 from napari.components.dims import Dims
 from napari.settings._constants import LoopMode
 from napari.utils.translations import trans
@@ -44,8 +47,7 @@ class QtDims(QWidget):
         # True / False if slider is or is not displayed
         self._displayed_sliders = []
 
-        self._animation_thread = None
-        self._animation_worker = None
+        self._animation_thread = AnimationThread(self)
 
         # Initialises the layout:
         layout = QVBoxLayout()
@@ -293,23 +295,27 @@ class QtDims(QWidget):
         if axis >= self.dims.ndim:
             raise IndexError(trans._('axis argument out of range'))
 
-        if self.is_playing:
-            if self._animation_worker.axis == axis:
-                self.slider_widgets[axis]._update_play_settings(
-                    fps, loop_mode, frame_range
-                )
-                return
-
-            self.stop()
+        if self.is_playing and self._animation_thread.axis == axis:
+            self.slider_widgets[axis]._update_play_settings(
+                fps, loop_mode, frame_range
+            )
+            return
 
         # we want to avoid playing a dimension that does not have a slider
         # (like X or Y, or a third dimension in volume view.)
         if self._displayed_sliders[axis]:
-            work = self.slider_widgets[axis]._play(fps, loop_mode, frame_range)
-            if work:
-                self._animation_worker, self._animation_thread = work
+            if self._animation_thread.isRunning():
+                self._animation_thread.slider.play_button._handle_stop()
+            self.slider_widgets[axis]._update_play_settings(
+                fps, loop_mode, frame_range
+            )
+            self._animation_thread.set_slider(self.slider_widgets[axis])
+            self._animation_thread.frame_requested.connect(self._set_frame)
+            if not self._animation_thread.isRunning():
+                self._animation_thread.start()
             else:
-                self._animation_worker, self._animation_thread = None, None
+                self._animation_thread.slider.play_button._handle_start()
+
         else:
             warnings.warn(
                 trans._(
@@ -321,23 +327,13 @@ class QtDims(QWidget):
     @Slot()
     def stop(self):
         """Stop axis animation"""
-        if self._animation_worker is not None:
-            # Thread will be stop by the worker
-            self._animation_worker._stop()
-
-    @Slot()
-    def cleaned_worker(self):
-        self._animation_thread = None
-        self._animation_worker = None
-        self.dims._play_ready = True
+        self._animation_thread._stop()
 
     @property
     def is_playing(self):
         """Return True if any axis is currently animated."""
         try:
-            return (
-                self._animation_thread and self._animation_thread.isRunning()
-            )
+            return not self._animation_thread._waiter.is_set()
         except RuntimeError as e:  # pragma: no cover
             if (
                 'wrapped C/C++ object of type' not in e.args[0]
