@@ -1,8 +1,8 @@
 from qtpy.QtCore import Qt
 from qtpy.QtWidgets import QDialog, QLabel, QPushButton, QVBoxLayout
 
-from ...settings import get_settings
-from ..qt_resources import get_stylesheet
+from napari._qt.qt_resources import get_stylesheet
+from napari.settings import get_settings
 
 
 class WarnPopup(QDialog):
@@ -11,8 +11,8 @@ class WarnPopup(QDialog):
     def __init__(
         self,
         parent=None,
-        text: str = "",
-    ):
+        text: str = '',
+    ) -> None:
         super().__init__(parent)
 
         self.setWindowFlags(Qt.WindowType.FramelessWindowHint)
@@ -26,7 +26,7 @@ class WarnPopup(QDialog):
         self._message.setText(text)
         self._message.setWordWrap(True)
         self._xbutton.clicked.connect(self._close)
-        self._xbutton.setStyleSheet("background-color: rgba(0, 0, 0, 0);")
+        self._xbutton.setStyleSheet('background-color: rgba(0, 0, 0, 0);')
 
         # Layout
         main_layout = QVBoxLayout()
