@@ -1,19 +1,21 @@
-"""Provides a QtPluginSorter that allows the user to change plugin call order.
-"""
+"""Provides a QtPluginSorter that allows the user to change plugin call order."""
+
 from __future__ import annotations
 
 import re
-from typing import TYPE_CHECKING, List, Optional, Union
+from typing import TYPE_CHECKING, Optional, Union
 
 from napari_plugin_engine import HookCaller, HookImplementation
 from qtpy.QtCore import QEvent, Qt, Signal, Slot
 from qtpy.QtWidgets import (
+    QAbstractItemView,
     QCheckBox,
     QComboBox,
     QFrame,
     QGraphicsOpacityEffect,
     QHBoxLayout,
     QLabel,
+    QListView,
     QListWidget,
     QListWidgetItem,
     QSizePolicy,
@@ -22,11 +24,11 @@ from qtpy.QtWidgets import (
 )
 from superqt import QElidingLabel
 
-from ...plugins import plugin_manager as napari_plugin_manager
-from ...settings import get_settings
-from ...utils.translations import trans
-from ..utils import drag_with_pixmap
-from .qt_tooltip import QtToolTipLabel
+from napari._qt.utils import drag_with_pixmap
+from napari._qt.widgets.qt_tooltip import QtToolTipLabel
+from napari.plugins import plugin_manager as napari_plugin_manager
+from napari.settings import get_settings
+from napari.utils.translations import trans
 
 if TYPE_CHECKING:
     from napari_plugin_engine import PluginManager
@@ -35,20 +37,20 @@ if TYPE_CHECKING:
 def rst2html(text):
     def ref(match):
         _text = match.groups()[0].split()[0]
-        if _text.startswith("~"):
-            _text = _text.split(".")[-1]
+        if _text.startswith('~'):
+            _text = _text.split('.')[-1]
         return f'``{_text}``'
 
     def link(match):
         _text, _link = match.groups()[0].split('<')
         return f'<a href="{_link.rstrip(">")}">{_text.strip()}</a>'
 
-    text = re.sub(r'\*\*([^\*]+)\*\*', '<strong>\\1</strong>', text)
-    text = re.sub(r'\*([^\*]+)\*', '<em>\\1</em>', text)
-    text = re.sub(r':[a-z]+:`([^`]+)`', ref, text, re.DOTALL)
-    text = re.sub(r'`([^`]+)`_', link, text, re.DOTALL)
+    text = re.sub(r'\*\*([^*]+)\*\*', '<strong>\\1</strong>', text)
+    text = re.sub(r'\*([^*]+)\*', '<em>\\1</em>', text)
+    text = re.sub(r':[a-z]+:`([^`]+)`', ref, text, flags=re.DOTALL)
+    text = re.sub(r'`([^`]+)`_', link, text, flags=re.DOTALL)
     text = re.sub(r'``([^`]+)``', '<code>\\1</code>', text)
-    return text.replace("\n", "<br>")
+    return text.replace('\n', '<br>')
 
 
 class ImplementationListItem(QFrame):
@@ -76,7 +78,7 @@ class ImplementationListItem(QFrame):
 
     on_changed = Signal()  # when user changes whether plugin is enabled.
 
-    def __init__(self, item: QListWidgetItem, parent: QWidget = None):
+    def __init__(self, item: QListWidgetItem, parent: QWidget = None) -> None:
         super().__init__(parent)
         self.item = item
         self.opacity = QGraphicsOpacityEffect(self)
@@ -87,7 +89,7 @@ class ImplementationListItem(QFrame):
         self.position_label = QLabel()
         self.update_position_label()
 
-        self.setToolTip(trans._("Click and drag to change call order"))
+        self.setToolTip(trans._('Click and drag to change call order'))
         self.plugin_name_label = QElidingLabel()
         self.plugin_name_label.setObjectName('small_text')
         self.plugin_name_label.setText(item.hook_implementation.plugin_name)
@@ -103,7 +105,7 @@ class ImplementationListItem(QFrame):
 
         self.enabled_checkbox = QCheckBox(self)
         self.enabled_checkbox.setToolTip(
-            trans._("Uncheck to disable this plugin")
+            trans._('Uncheck to disable this plugin')
         )
         self.enabled_checkbox.stateChanged.connect(self._set_enabled)
         self.enabled_checkbox.setChecked(
@@ -146,7 +148,7 @@ class QtHookImplementationListWidget(QListWidget):
     ----------
     parent : QWidget, optional
         Optional parent widget, by default None
-    hook : HookCaller, optional
+    hook_caller : HookCaller, optional
         The ``HookCaller`` for which to show implementations. by default None
         (i.e. no hooks shown)
 
@@ -163,12 +165,12 @@ class QtHookImplementationListWidget(QListWidget):
         self,
         parent: Optional[QWidget] = None,
         hook_caller: Optional[HookCaller] = None,
-    ):
+    ) -> None:
         super().__init__(parent)
-        self.setDefaultDropAction(Qt.MoveAction)
+        self.setDefaultDropAction(Qt.DropAction.MoveAction)
         self.setDragEnabled(True)
-        self.setDragDropMode(self.InternalMove)
-        self.setSelectionMode(self.SingleSelection)
+        self.setDragDropMode(QListView.InternalMove)
+        self.setSelectionMode(QAbstractItemView.SingleSelection)
         self.setAcceptDrops(True)
         self.setSpacing(1)
         self.setMinimumHeight(1)
@@ -207,7 +209,7 @@ class QtHookImplementationListWidget(QListWidget):
         hook_implementation : HookImplementation
             The hook implementation object to add to the list.
         """
-        item = QListWidgetItem(parent=self)
+        item = QListWidgetItem(self)
         item.hook_implementation = hook_implementation
         self.addItem(item)
         widg = ImplementationListItem(item, parent=self)
@@ -228,12 +230,12 @@ class QtHookImplementationListWidget(QListWidget):
         order = [self.item(r).hook_implementation for r in range(self.count())]
         self.order_changed.emit(order)
 
-    def startDrag(self, supportedActions: Qt.DropActions):
+    def startDrag(self, supported_actions):
         drag = drag_with_pixmap(self)
-        drag.exec_(supportedActions, Qt.MoveAction)
+        drag.exec_(supported_actions, Qt.DropAction.MoveAction)
 
     @Slot(list)
-    def permute_hook(self, order: List[HookImplementation]):
+    def permute_hook(self, order: list[HookImplementation]):
         """Rearrage the call order of the hooks for the current hook impl.
 
         Parameters
@@ -291,7 +293,7 @@ class QtPluginSorter(QWidget):
         parent: Optional[QWidget] = None,
         initial_hook: Optional[str] = None,
         firstresult_only: bool = True,
-    ):
+    ) -> None:
         super().__init__(parent)
 
         self.plugin_manager = plugin_manager
@@ -305,21 +307,22 @@ class QtPluginSorter(QWidget):
             if not hook_caller.spec:
                 continue
 
-            if firstresult_only:
-                # if the firstresult_only option is set
-                # we only want to include hook_specifications that declare the
-                # "firstresult" option as True.
-                if not hook_caller.spec.opts.get('firstresult', False):
-                    continue
+            # if the firstresult_only option is set
+            # we only want to include hook_specifications that declare the
+            # "firstresult" option as True.
+            if firstresult_only and not hook_caller.spec.opts.get(
+                'firstresult', False
+            ):
+                continue
             self.hook_combo_box.addItem(
-                name.replace("napari_", ""), hook_caller
+                name.replace('napari_', ''), hook_caller
             )
 
         self.plugin_manager.events.disabled.connect(self._on_disabled)
         self.plugin_manager.events.registered.connect(self.refresh)
 
         self.hook_combo_box.setToolTip(
-            trans._("select the hook specification to reorder")
+            trans._('select the hook specification to reorder')
         )
         self.hook_combo_box.currentIndexChanged.connect(self._on_hook_change)
         self.hook_list = QtHookImplementationListWidget(parent=self)
@@ -335,7 +338,7 @@ class QtPluginSorter(QWidget):
 
         self.docstring = QLabel(self)
         self.info = QtToolTipLabel(self)
-        self.info.setObjectName("info_icon")
+        self.info.setObjectName('info_icon')
         doc_lay = QHBoxLayout()
         doc_lay.addWidget(self.docstring)
         doc_lay.setStretch(0, 1)
@@ -368,7 +371,7 @@ class QtPluginSorter(QWidget):
         hook : str
             Name of the new hook specification to show.
         """
-        self.hook_combo_box.setCurrentText(hook.replace("napari_", ''))
+        self.hook_combo_box.setCurrentText(hook.replace('napari_', ''))
 
     def _on_hook_change(self, index):
         hook_caller = self.hook_combo_box.currentData()
@@ -376,7 +379,7 @@ class QtPluginSorter(QWidget):
 
         if hook_caller:
             doc = hook_caller.spec.function.__doc__
-            html = rst2html(doc.split("Parameters")[0].strip())
+            html = rst2html(doc.split('Parameters')[0].strip())
             summary, fulldoc = html.split('<br>', 1)
             while fulldoc.startswith('<br>'):
                 fulldoc = fulldoc[4:]
