@@ -44,23 +44,23 @@ class QtLabeledProgressBar(QWidget):
         base_layout.addLayout(pbar_layout)
 
         line = QFrame(self)
-        line.setObjectName("QtCustomTitleBarLine")
+        line.setObjectName('QtCustomTitleBarLine')
         line.setFixedHeight(1)
         base_layout.addWidget(line)
 
         self.setLayout(base_layout)
 
     @rename_argument(
-        from_name="min",
-        to_name="min_val",
-        version="0.6.0",
-        since_version="0.4.18",
+        from_name='min',
+        to_name='min_val',
+        version='0.6.0',
+        since_version='0.4.18',
     )
     @rename_argument(
-        from_name="max",
-        to_name="max_val",
-        version="0.6.0",
-        since_version="0.4.18",
+        from_name='max',
+        to_name='max_val',
+        version='0.6.0',
+        since_version='0.4.18',
     )
     def setRange(self, min_val, max_val):
         self.qt_progress_bar.setRange(min_val, max_val)
@@ -115,7 +115,7 @@ class QtProgressBarGroup(QWidget):
         pbr_group_layout.setContentsMargins(0, 0, 0, 0)
 
         line = QFrame(self)
-        line.setObjectName("QtCustomTitleBarLine")
+        line.setObjectName('QtCustomTitleBarLine')
         line.setFixedHeight(1)
         pbr_group_layout.addWidget(line)
 
