@@ -13,7 +13,7 @@ from qtpy.QtWidgets import (
     QWidget,
 )
 
-from ...utils.translations import trans
+from napari.utils.translations import trans
 
 
 class QtFontSizePreview(QFrame):
@@ -28,10 +28,12 @@ class QtFontSizePreview(QFrame):
         Preview text to display. Default is None.
     """
 
-    def __init__(self, parent: QWidget = None, text: str = None):
+    def __init__(
+        self, parent: QWidget = None, text: typing.Optional[str] = None
+    ) -> None:
         super().__init__(parent)
 
-        self._text = text or ""
+        self._text = text or ''
 
         # Widget
         self._preview = QPlainTextEdit(self)
@@ -100,17 +102,17 @@ class QtSizeSliderPreviewWidget(QWidget):
     def __init__(
         self,
         parent: QWidget = None,
-        description: str = None,
-        preview_text: str = None,
-        value: int = None,
+        description: typing.Optional[str] = None,
+        preview_text: typing.Optional[str] = None,
+        value: typing.Optional[int] = None,
         min_value: int = 1,
         max_value: int = 50,
-        unit: str = "px",
-    ):
+        unit: str = 'px',
+    ) -> None:
         super().__init__(parent)
 
-        description = description or ""
-        preview_text = preview_text or ""
+        description = description or ''
+        preview_text = preview_text or ''
         self._value = value if value else self.fontMetrics().height()
         self._min_value = min_value
         self._max_value = max_value
@@ -136,7 +138,7 @@ class QtSizeSliderPreviewWidget(QWidget):
         self._slider.setMinimum(min_value)
         self._slider.setMaximum(max_value)
         self._preview.setText(preview_text)
-        self._preview_label.setText(trans._("preview"))
+        self._preview_label.setText(trans._('preview'))
         self._preview_label.setAlignment(Qt.AlignmentFlag.AlignHCenter)
         self.setFocusProxy(self._lineedit)
 
@@ -176,7 +178,7 @@ class QtSizeSliderPreviewWidget(QWidget):
 
     def _update_line_width(self):
         """Update width ofg line text edit."""
-        txt = "m" * (1 + len(str(self._max_value)))
+        txt = 'm' * (1 + len(str(self._max_value)))
         fm = self._lineedit.fontMetrics()
         if hasattr(fm, 'horizontalAdvance'):
             # Qt >= 5.11
@@ -189,7 +191,7 @@ class QtSizeSliderPreviewWidget(QWidget):
 
     def _update_value(self, value: typing.Union[int, str]):
         """Update internal value and emit if changed."""
-        if value == "":
+        if value == '':
             value = int(self._value)
 
         value = int(value)
@@ -205,7 +207,7 @@ class QtSizeSliderPreviewWidget(QWidget):
         self._value = value
         self._refresh(self._value)
 
-    def _refresh(self, value: int = None):
+    def _refresh(self, value: typing.Optional[int] = None):
         """Refresh the value on all subwidgets."""
         value = value or self._value
         self.blockSignals(True)
@@ -302,7 +304,7 @@ class QtSizeSliderPreviewWidget(QWidget):
         if value >= self._max_value:
             raise ValueError(
                 trans._(
-                    "Minimum value must be smaller than {max_value}",
+                    'Minimum value must be smaller than {max_value}',
                     max_value=self._max_value,
                 )
             )
@@ -334,7 +336,7 @@ class QtSizeSliderPreviewWidget(QWidget):
         if value <= self._min_value:
             raise ValueError(
                 trans._(
-                    "Maximum value must be larger than {min_value}",
+                    'Maximum value must be larger than {min_value}',
                     min_value=self._min_value,
                 )
             )
