@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from qtpy.QtCore import Qt, Signal
+from qtpy.QtCore import QSize, Qt, Signal
 from qtpy.QtGui import QKeySequence, QPainter
 from qtpy.QtWidgets import (
     QFormLayout,
@@ -12,7 +12,9 @@ from qtpy.QtWidgets import (
     QWidget,
 )
 
-from ...utils.translations import trans
+from napari.utils.action_manager import action_manager
+from napari.utils.interactions import Shortcut
+from napari.utils.translations import trans
 
 
 class QtWelcomeLabel(QLabel):
@@ -26,26 +28,26 @@ class QtShortcutLabel(QLabel):
 class QtWelcomeWidget(QWidget):
     """Welcome widget to display initial information and shortcuts to user."""
 
-    sig_dropped = Signal("QEvent")
+    sig_dropped = Signal('QEvent')
 
-    def __init__(self, parent):
+    def __init__(self, parent) -> None:
         super().__init__(parent)
 
         # Create colored icon using theme
         self._image = QLabel()
-        self._image.setObjectName("logo_silhouette")
+        self._image.setObjectName('logo_silhouette')
         self._image.setMinimumSize(300, 300)
         self._label = QtWelcomeLabel(
             trans._(
-                "Drag image(s) here to open\nor\nUse the menu shortcuts below:"
+                'Drag image(s) here to open\nor\nUse the menu shortcuts below:'
             )
         )
 
         # Widget setup
         self.setAutoFillBackground(True)
         self.setAcceptDrops(True)
-        self._image.setAlignment(Qt.AlignCenter)
-        self._label.setAlignment(Qt.AlignCenter)
+        self._image.setAlignment(Qt.AlignmentFlag.AlignCenter)
+        self._label.setAlignment(Qt.AlignmentFlag.AlignCenter)
 
         # Layout
         text_layout = QVBoxLayout()
@@ -53,15 +55,24 @@ class QtWelcomeWidget(QWidget):
 
         # TODO: Use action manager for shortcut query and handling
         shortcut_layout = QFormLayout()
-        sc = QKeySequence('Ctrl+O').toString(QKeySequence.NativeText)
-        shortcut_layout.addRow(
-            QtShortcutLabel(sc),
-            QtShortcutLabel(trans._("open image(s)")),
+        sc = QKeySequence('Ctrl+N', QKeySequence.PortableText).toString(
+            QKeySequence.NativeText
         )
-        sc = QKeySequence('Ctrl+Alt+/').toString(QKeySequence.NativeText)
         shortcut_layout.addRow(
             QtShortcutLabel(sc),
-            QtShortcutLabel(trans._("show all key bindings")),
+            QtShortcutLabel(trans._('New Image from Clipboard')),
+        )
+        sc = QKeySequence('Ctrl+O', QKeySequence.PortableText).toString(
+            QKeySequence.NativeText
+        )
+        shortcut_layout.addRow(
+            QtShortcutLabel(sc),
+            QtShortcutLabel(trans._('open image(s)')),
+        )
+        self._shortcut_label = QtShortcutLabel('')
+        shortcut_layout.addRow(
+            self._shortcut_label,
+            QtShortcutLabel(trans._('show all key bindings')),
         )
         shortcut_layout.setSpacing(0)
 
@@ -74,6 +85,24 @@ class QtWelcomeWidget(QWidget):
         layout.addStretch()
 
         self.setLayout(layout)
+        self._show_shortcuts_updated()
+        action_manager.events.shorcut_changed.connect(
+            self._show_shortcuts_updated
+        )
+
+    def minimumSizeHint(self):
+        """
+        Overwrite minimum size to allow creating small viewer instance
+        """
+        return QSize(100, 100)
+
+    def _show_shortcuts_updated(self):
+        shortcut_list = list(
+            action_manager._shortcuts['napari:show_shortcuts']
+        )
+        if not shortcut_list:
+            return
+        self._shortcut_label.setText(Shortcut(shortcut_list[0]).platform)
 
     def paintEvent(self, event):
         """Override Qt method.
@@ -109,11 +138,13 @@ class QtWelcomeWidget(QWidget):
 
         Parameters
         ----------
-        event : qtpy.QtCore.QEvent
+        event : qtpy.QtCore.QDragEnterEvent
             Event from the Qt context.
         """
-        self._update_property("drag", True)
+        self._update_property('drag', True)
         if event.mimeData().hasUrls():
+            viewer = self.parentWidget().nativeParentWidget()._qt_viewer
+            viewer._set_drag_status()
             event.accept()
         else:
             event.ignore()
@@ -125,10 +156,10 @@ class QtWelcomeWidget(QWidget):
 
         Parameters
         ----------
-        event : qtpy.QtCore.QEvent
+        event : qtpy.QtCore.QDragLeaveEvent
             Event from the Qt context.
         """
-        self._update_property("drag", False)
+        self._update_property('drag', False)
 
     def dropEvent(self, event):
         """Override Qt method.
@@ -137,10 +168,10 @@ class QtWelcomeWidget(QWidget):
 
         Parameters
         ----------
-        event : qtpy.QtCore.QEvent
+        event : qtpy.QtCore.QDropEvent
             Event from the Qt context.
         """
-        self._update_property("drag", False)
+        self._update_property('drag', False)
         self.sig_dropped.emit(event)
 
 
@@ -149,10 +180,12 @@ class QtWidgetOverlay(QStackedWidget):
     Stacked widget providing switching between the widget and a welcome page.
     """
 
-    sig_dropped = Signal("QEvent")
+    sig_dropped = Signal('QEvent')
     resized = Signal()
+    leave = Signal()
+    enter = Signal()
 
-    def __init__(self, parent, widget):
+    def __init__(self, parent, widget) -> None:
         super().__init__(parent)
 
         self._overlay = QtWelcomeWidget(self)
@@ -170,5 +203,16 @@ class QtWidgetOverlay(QStackedWidget):
         self.setCurrentIndex(int(visible))
 
     def resizeEvent(self, event):
+        """Emit our own event when canvas was resized."""
         self.resized.emit()
         return super().resizeEvent(event)
+
+    def enterEvent(self, event):
+        """Emit our own event when mouse enters the canvas."""
+        self.enter.emit()
+        super().enterEvent(event)
+
+    def leaveEvent(self, event):
+        """Emit our own event when mouse leaves the canvas."""
+        self.leave.emit()
+        super().leaveEvent(event)
