@@ -24,13 +24,12 @@ def test_cli_works(monkeypatch, capsys):
     assert 'napari command line viewer.' in str(capsys.readouterr())
 
 
-def test_cli_shows_plugins(napari_plugin_manager, monkeypatch, capsys):
+def test_cli_shows_plugins(monkeypatch, capsys, tmp_plugin):
     """Test the cli --info runs and shows plugins"""
     monkeypatch.setattr(sys, 'argv', ['napari', '--info'])
     with pytest.raises(SystemExit):
         __main__._run()
-    # this is because sckit-image is OUR builtin providing sample_data
-    assert 'scikit-image' in str(capsys.readouterr())
+    assert tmp_plugin.name in str(capsys.readouterr())
 
 
 def test_cli_parses_unknowns(mock_run, monkeypatch, make_napari_viewer):
@@ -38,7 +37,7 @@ def test_cli_parses_unknowns(mock_run, monkeypatch, make_napari_viewer):
     v = make_napari_viewer()  # our mock view_path will return this object
 
     def assert_kwargs(*args, **kwargs):
-        assert ["file"] in args
+        assert ['file'] in args
         assert kwargs['contrast_limits'] == (0, 1)
 
     # testing all the variants of literal_evals
@@ -68,7 +67,7 @@ def test_cli_raises(monkeypatch):
         m.setattr(sys, 'argv', ['napari', 'path/to/file', '--nonsense'])
         with pytest.raises(SystemExit) as e:
             __main__._run()
-        assert str(e.value) == 'error: unrecognized arguments: --nonsense'
+        assert str(e.value) == 'error: unrecognized argument: --nonsense'
 
     with monkeypatch.context() as m:
         m.setattr(sys, 'argv', ['napari', 'path/to/file', '--gamma'])
@@ -102,7 +101,44 @@ def test_cli_passes_kwargs(qt_open, mock_run, monkeypatch, make_napari_viewer):
 
     qt_open.assert_called_once_with(
         ['file'],
-        stack=False,
+        stack=[],
+        plugin=None,
+        layer_type=None,
+        name='some name',
+    )
+    mock_run.assert_called_once_with(gui_exceptions=True)
+
+
+@mock.patch('napari._qt.qt_viewer.QtViewer._qt_open')
+def test_cli_passes_kwargs_stack(
+    qt_open, mock_run, monkeypatch, make_napari_viewer
+):
+    """test that we can parse layer keyword arg variants"""
+    v = make_napari_viewer()
+
+    with mock.patch('napari.Viewer', return_value=v):
+        with monkeypatch.context() as m:
+            m.setattr(
+                sys,
+                'argv',
+                [
+                    'n',
+                    'file',
+                    '--stack',
+                    'file1',
+                    'file2',
+                    '--stack',
+                    'file3',
+                    'file4',
+                    '--name',
+                    'some name',
+                ],
+            )
+            __main__._run()
+
+    qt_open.assert_called_once_with(
+        ['file'],
+        stack=[['file1', 'file2'], ['file3', 'file4']],
         plugin=None,
         layer_type=None,
         name='some name',
@@ -120,10 +156,10 @@ def test_cli_retains_viewer_ref(mock_run, monkeypatch, make_napari_viewer):
         # it forces garbage collection, and then makes sure that at least one
         # additional reference to our viewer exists.
         gc.collect()
-        if sys.getrefcount(v) <= ref_count:
+        if sys.getrefcount(v) <= ref_count:  # pragma: no cover
             raise AssertionError(
-                "Reference to napari.viewer has been lost by "
-                "the time the event loop started in napari.__main__"
+                'Reference to napari.viewer has been lost by '
+                'the time the event loop started in napari.__main__'
             )
 
     mock_run.side_effect = _check_refs
