@@ -2,8 +2,8 @@ from copy import deepcopy
 
 from jsonschema.validators import validator_for
 
-from napari._vendor.qt_json_builder.qt_jsonschema_form import widgets
-from napari._vendor.qt_json_builder.qt_jsonschema_form.defaults import compute_defaults
+from . import widgets
+from .defaults import compute_defaults
 
 
 def get_widget_state(schema, state=None):
@@ -29,6 +29,7 @@ class WidgetBuilder:
             "plugins": widgets.PluginWidget,
             "shortcuts": widgets.ShortcutsWidget,
             "extension2reader": widgets.Extension2ReaderWidget,
+            "highlight": widgets.HighlightPreviewWidget,
         },
         "number": {
             "spin": widgets.SpinDoubleSchemaWidget,
@@ -48,7 +49,7 @@ class WidgetBuilder:
             "text": widgets.TextSchemaWidget,
             "range": widgets.IntegerRangeSchemaWidget,
             "enum": widgets.EnumSchemaWidget,
-            "highlight": widgets.HighlightSizePreviewWidget,
+            "font_size": widgets.FontSizeSchemaWidget,
         },
         "array": {
             "array": widgets.ArraySchemaWidget,
