@@ -4,7 +4,7 @@ import numpy as np
 def test_camera(make_napari_viewer):
     """Test vispy camera creation in 2D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
@@ -24,7 +24,7 @@ def test_camera(make_napari_viewer):
 def test_vispy_camera_update_from_model(make_napari_viewer):
     """Test vispy camera update from model in 2D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
@@ -49,7 +49,7 @@ def test_vispy_camera_update_from_model(make_napari_viewer):
 def test_camera_model_update_from_vispy(make_napari_viewer):
     """Test camera model updates from vispy in 2D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
@@ -75,7 +75,7 @@ def test_camera_model_update_from_vispy(make_napari_viewer):
 def test_3D_camera(make_napari_viewer):
     """Test vispy camera creation in 3D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
@@ -94,7 +94,7 @@ def test_3D_camera(make_napari_viewer):
 def test_vispy_camera_update_from_model_3D(make_napari_viewer):
     """Test vispy camera update from model in 3D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
@@ -118,7 +118,7 @@ def test_vispy_camera_update_from_model_3D(make_napari_viewer):
 def test_camera_model_update_from_vispy_3D(make_napari_viewer):
     """Test camera model updates from vispy in 3D."""
     viewer = make_napari_viewer()
-    vispy_camera = viewer.window.qt_viewer.camera
+    vispy_camera = viewer.window._qt_viewer.canvas.camera
 
     np.random.seed(0)
     data = np.random.random((11, 11, 11))
