@@ -1,9 +1,7 @@
-from typing import Type
-
 import numpy as np
 from vispy.scene import ArcballCamera, BaseCamera, PanZoomCamera
 
-from napari._vispy.utils.quaternion import quaternion2euler
+from napari._vispy.utils.quaternion import quaternion2euler_degrees
 
 
 class VispyCamera:
@@ -58,9 +56,7 @@ class VispyCamera:
 
         if self._view.camera == self._3D_camera:
             # Do conversion from quaternion representation to euler angles
-            angles = quaternion2euler(
-                self._view.camera._quaternion, degrees=True
-            )
+            angles = quaternion2euler_degrees(self._view.camera._quaternion)
         else:
             angles = (0, 0, 90)
         return angles
@@ -212,8 +208,8 @@ def viewbox_key_event(event):
 
 
 def add_mouse_pan_zoom_toggles(
-    vispy_camera_cls: Type[BaseCamera],
-) -> Type[BaseCamera]:
+    vispy_camera_cls: type[BaseCamera],
+) -> type[BaseCamera]:
     """Add separate mouse pan and mouse zoom toggles to VisPy.
 
     By default, VisPy uses an ``interactive`` toggle that turns *both*
@@ -228,7 +224,7 @@ def add_mouse_pan_zoom_toggles(
 
     Returns
     -------
-        A decorated VisPy camera class.
+    A decorated VisPy camera class.
     """
 
     class _vispy_camera_cls(vispy_camera_cls):
@@ -240,8 +236,9 @@ def add_mouse_pan_zoom_toggles(
         def viewbox_mouse_event(self, event):
             if (
                 self.mouse_zoom
-                and event.type == 'mouse_wheel'
-                or self.mouse_pan
+                and event.type in ('mouse_wheel', 'gesture_zoom')
+            ) or (
+                self.mouse_pan
                 and event.type
                 in ('mouse_move', 'mouse_press', 'mouse_release')
             ):
