@@ -10,18 +10,22 @@ from napari.utils.events import disconnect_events
 
 
 class VispyPointsLayer(VispyBaseLayer):
-    _highlight_color = (0, 0.6, 1)
+    node: PointsVisual
 
     def __init__(self, layer) -> None:
         node = PointsVisual()
         super().__init__(layer, node)
 
         self.layer.events.symbol.connect(self._on_data_change)
-        self.layer.events.edge_width.connect(self._on_data_change)
-        self.layer.events.edge_width_is_relative.connect(self._on_data_change)
-        self.layer.events.edge_color.connect(self._on_data_change)
-        self.layer._edge.events.colors.connect(self._on_data_change)
-        self.layer._edge.events.color_properties.connect(self._on_data_change)
+        self.layer.events.border_width.connect(self._on_data_change)
+        self.layer.events.border_width_is_relative.connect(
+            self._on_data_change
+        )
+        self.layer.events.border_color.connect(self._on_data_change)
+        self.layer._border.events.colors.connect(self._on_data_change)
+        self.layer._border.events.color_properties.connect(
+            self._on_data_change
+        )
         self.layer.events.face_color.connect(self._on_data_change)
         self.layer._face.events.colors.connect(self._on_data_change)
         self.layer._face.events.color_properties.connect(self._on_data_change)
@@ -43,31 +47,31 @@ class VispyPointsLayer(VispyBaseLayer):
             # always pass one invisible point to avoid issues
             data = np.zeros((1, self.layer._slice_input.ndisplay))
             size = np.zeros(1)
-            edge_color = np.array([[0.0, 0.0, 0.0, 1.0]], dtype=np.float32)
+            border_color = np.array([[0.0, 0.0, 0.0, 1.0]], dtype=np.float32)
             face_color = np.array([[1.0, 1.0, 1.0, 1.0]], dtype=np.float32)
-            edge_width = np.zeros(1)
+            border_width = np.zeros(1)
             symbol = ['o']
         else:
             data = self.layer._view_data
             size = self.layer._view_size
-            edge_color = self.layer._view_edge_color
+            border_color = self.layer._view_border_color
             face_color = self.layer._view_face_color
-            edge_width = self.layer._view_edge_width
-            symbol = self.layer._view_symbol
+            border_width = self.layer._view_border_width
+            symbol = [str(x) for x in self.layer._view_symbol]
 
-        set_data = self.node._subvisuals[0].set_data
+        set_data = self.node.points_markers.set_data
 
         # use only last dimension to scale point sizes, see #5582
         scale = self.layer.scale[-1]
 
-        if self.layer.edge_width_is_relative:
-            edge_kw = {
+        if self.layer.border_width_is_relative:
+            border_kw = {
                 'edge_width': None,
-                'edge_width_rel': edge_width,
+                'edge_width_rel': border_width,
             }
         else:
-            edge_kw = {
-                'edge_width': edge_width * scale,
+            border_kw = {
+                'edge_width': border_width * scale,
                 'edge_width_rel': None,
             }
 
@@ -75,9 +79,10 @@ class VispyPointsLayer(VispyBaseLayer):
             data[:, ::-1],
             size=size * scale,
             symbol=symbol,
-            edge_color=edge_color,
+            # edge_color is the name of the vispy marker visual kwarg
+            edge_color=border_color,
             face_color=face_color,
-            **edge_kw,
+            **border_kw,
         )
 
         self.reset()
@@ -90,12 +95,12 @@ class VispyPointsLayer(VispyBaseLayer):
             if data.ndim == 1:
                 data = np.expand_dims(data, axis=0)
             size = self.layer._view_size[self.layer._highlight_index]
-            edge_width = self.layer._view_edge_width[
+            border_width = self.layer._view_border_width[
                 self.layer._highlight_index
             ]
-            if self.layer.edge_width_is_relative:
-                edge_width = (
-                    edge_width
+            if self.layer.border_width_is_relative:
+                border_width = (
+                    border_width
                     * self.layer._view_size[self.layer._highlight_index][-1]
                 )
             symbol = self.layer._view_symbol[self.layer._highlight_index]
@@ -103,19 +108,20 @@ class VispyPointsLayer(VispyBaseLayer):
             data = np.zeros((1, self.layer._slice_input.ndisplay))
             size = 0
             symbol = ['o']
-            edge_width = np.array([0])
+            border_width = np.array([0])
 
         scale = self.layer.scale[-1]
-        scaled_highlight = (
-            settings.appearance.highlight_thickness * self.layer.scale_factor
-        )
+        highlight_thickness = settings.appearance.highlight.highlight_thickness
+        scaled_highlight = highlight_thickness * self.layer.scale_factor
+        scaled_size = (size + border_width) * scale
+        highlight_color = tuple(settings.appearance.highlight.highlight_color)
 
-        self.node._subvisuals[1].set_data(
+        self.node.selection_markers.set_data(
             data[:, ::-1],
-            size=(size + edge_width) * scale,
+            size=scaled_size,
             symbol=symbol,
             edge_width=scaled_highlight * 2,
-            edge_color=self._highlight_color,
+            edge_color=highlight_color,
             face_color=transform_color('transparent'),
         )
 
@@ -124,15 +130,14 @@ class VispyPointsLayer(VispyBaseLayer):
             or 0 in self.layer._highlight_box.shape
         ):
             pos = np.zeros((1, self.layer._slice_input.ndisplay))
-            width = 0
+            highlight_thickness = 0
         else:
             pos = self.layer._highlight_box
-            width = scaled_highlight
 
-        self.node._subvisuals[2].set_data(
+        self.node.highlight_lines.set_data(
             pos=pos[:, ::-1],
-            color=self._highlight_color,
-            width=width,
+            color=highlight_color,
+            width=highlight_thickness,
         )
 
         self.node.update()
@@ -151,8 +156,7 @@ class VispyPointsLayer(VispyBaseLayer):
 
     def _get_text_node(self):
         """Function to get the text node from the Compound visual"""
-        text_node = self.node._subvisuals[-1]
-        return text_node
+        return self.node.text
 
     def _on_text_change(self, event=None):
         if event is not None:
@@ -163,7 +167,7 @@ class VispyPointsLayer(VispyBaseLayer):
                 return
         self._update_text()
 
-    def _on_blending_change(self):
+    def _on_blending_change(self, event=None):
         """Function to set the blending mode"""
         points_blending_kwargs = BLENDING_MODES[self.layer.blending]
         self.node.set_gl_state(**points_blending_kwargs)
@@ -174,7 +178,7 @@ class VispyPointsLayer(VispyBaseLayer):
 
         # selection box is always without depth
         box_blending_kwargs = BLENDING_MODES['translucent_no_depth']
-        self.node._subvisuals[2].set_gl_state(**box_blending_kwargs)
+        self.node.highlight_lines.set_gl_state(**box_blending_kwargs)
 
         self.node.update()
 
@@ -183,13 +187,21 @@ class VispyPointsLayer(VispyBaseLayer):
 
     def _on_shading_change(self):
         shading = self.layer.shading
-        if shading == 'spherical':
-            self.node.spherical = True
-        else:
-            self.node.spherical = False
+        self.node.spherical = shading == 'spherical'
 
     def _on_canvas_size_limits_change(self):
-        self.node.canvas_size_limits = self.layer.canvas_size_limits
+        self.node.points_markers.canvas_size_limits = (
+            self.layer.canvas_size_limits
+        )
+        highlight_thickness = (
+            get_settings().appearance.highlight.highlight_thickness
+        )
+        low, high = self.layer.canvas_size_limits
+        self.node.selection_markers.canvas_size_limits = (
+            low + highlight_thickness,
+            high + highlight_thickness,
+        )
+        self.node.update()
 
     def reset(self):
         super().reset()
