@@ -1,9 +1,10 @@
 import numpy as np
 from vispy.color import Colormap as VispyColormap
 from vispy.geometry import MeshData
+from vispy.visuals.filters import TextureFilter
 
-from ..visuals.surface import SurfaceVisual
-from .base import VispyBaseLayer
+from napari._vispy.layers.base import VispyBaseLayer
+from napari._vispy.visuals.surface import SurfaceVisual
 
 
 class VispySurfaceLayer(VispyBaseLayer):
@@ -14,8 +15,10 @@ class VispySurfaceLayer(VispyBaseLayer):
     here https://github.com/vispy/vispy/blob/main/vispy/visuals/mesh.py
     """
 
-    def __init__(self, layer):
+    def __init__(self, layer) -> None:
         node = SurfaceVisual()
+        self._texture_filter = None
+        self._light_direction = (-1, 1, 1)
         self._meshdata = None
         super().__init__(layer, node)
 
@@ -25,6 +28,9 @@ class VispySurfaceLayer(VispyBaseLayer):
         )
         self.layer.events.gamma.connect(self._on_gamma_change)
         self.layer.events.shading.connect(self._on_shading_change)
+        self.layer.events.texture.connect(self._on_texture_change)
+        self.layer.events.texcoords.connect(self._on_texture_change)
+
         self.layer.wireframe.events.visible.connect(
             self._on_wireframe_visible_change
         )
@@ -43,59 +49,83 @@ class VispySurfaceLayer(VispyBaseLayer):
         self._on_data_change()
 
     def _on_data_change(self):
-        if len(self.layer._data_view) == 0 or len(self.layer._view_faces) == 0:
-            vertices = None
-            faces = None
-            vertex_values = np.array([0])
-        else:
+        vertices = None
+        faces = None
+        vertex_values = None
+        vertex_colors = None
+        if len(self.layer._data_view) and len(self.layer._view_faces):
             # Offsetting so pixels now centered
             # coerce to float to solve vispy/vispy#2007
             # reverse order to get zyx instead of xyz
             vertices = np.asarray(
                 self.layer._data_view[:, ::-1], dtype=np.float32
             )
-            # due to above xyz>zyx, also reverse order of faces to fix handedness of normals
+            # due to above xyz>zyx, also reverse order of faces to fix
+            # handedness of normals
             faces = self.layer._view_faces[:, ::-1]
-            vertex_values = self.layer._view_vertex_values
 
-        if (
-            vertices is not None
-            and self.layer._ndisplay == 3
-            and self.layer.ndim == 2
-        ):
-            vertices = np.pad(vertices, ((0, 0), (0, 1)))
+            values = self.layer._view_vertex_values
+            if len(values):
+                vertex_values = values
 
-        # manually detach filters when we go to 2D to avoid dimensionality issues
-        # see comments in napari#3475. The filter is set again after set_data!
-        if self.layer._ndisplay == 2:
-            filt = self.node.shading_filter
-            try:
-                self.node.detach(filt)
-                self.node.shading = None
-                self.node.shading_filter = None
-            except ValueError:
-                # sometimes we try to detach non-attached filters, which causes a ValueError
-                pass
+            colors = self.layer._view_vertex_colors
+            if len(colors):
+                vertex_colors = colors
+
+        # making sure the vertex data is 3D prevents shape errors with
+        # attached filters, instead of trying to attach/detach each time
+        if vertices is not None and vertices.shape[-1] == 2:
+            vertices = np.pad(
+                vertices,
+                ((0, 0), (0, 1)),
+                mode='constant',
+                constant_values=0,
+            )
+        assert vertices is None or vertices.shape[-1] == 3
 
         self.node.set_data(
-            vertices=vertices, faces=faces, vertex_values=vertex_values
+            vertices=vertices,
+            faces=faces,
+            vertex_values=vertex_values,
+            vertex_colors=vertex_colors,
         )
-
         # disable normals in 2D to avoid shape errors
-        if self.layer._ndisplay == 2:
-            meshdata = MeshData()
+        if self.layer._slice_input.ndisplay == 2:
+            self._meshdata = MeshData()
         else:
-            meshdata = self.node.mesh_data
-        self._meshdata = meshdata
-
+            self._meshdata = self.node.mesh_data
         self._on_face_normals_change()
         self._on_vertex_normals_change()
+
+        self._on_texture_change()
         self._on_shading_change()
 
         self.node.update()
+
         # Call to update order of translation values with new dims:
         self._on_matrix_change()
 
+    def _on_texture_change(self):
+        """Update or apply the texture filter"""
+        # texture images need to be flipped (np.flipud) because of how OpenGL
+        # expects the texture data to be ordered in memory we flip them here
+        # when setting up the TextureFilter so napari users can load images
+        # for textures normally
+        # https://registry.khronos.org/OpenGL-Refpages/gl4/html/glTexImage2D.xhtml
+        if self.layer._has_texture and self._texture_filter is None:
+            self._texture_filter = TextureFilter(
+                np.flipud(self.layer.texture),
+                self.layer.texcoords,
+            )
+            self.node.attach(self._texture_filter)
+        elif self.layer._has_texture:
+            self._texture_filter.texture = np.flipud(self.layer.texture)
+            self._texture_filter.texcoords = self.layer.texcoords
+
+        if self._texture_filter is not None:
+            self._texture_filter.enabled = self.layer._has_texture
+            self.node.update()
+
     def _on_colormap_change(self):
         if self.layer.gamma != 1:
             # when gamma!=1, we instantiate a new colormap with 256 control
@@ -106,7 +136,7 @@ class VispySurfaceLayer(VispyBaseLayer):
             cmap = VispyColormap(colors)
         else:
             cmap = VispyColormap(*self.layer.colormap)
-        if self.layer._ndisplay == 3:
+        if self.layer._slice_input.ndisplay == 3:
             self.node.view_program['texture2D_LUT'] = (
                 cmap.texture_lut() if (hasattr(cmap, 'texture_lut')) else None
             )
@@ -120,8 +150,9 @@ class VispySurfaceLayer(VispyBaseLayer):
 
     def _on_shading_change(self):
         shading = None if self.layer.shading == 'none' else self.layer.shading
-        if self.layer._ndisplay == 3:
+        if not self.node.mesh_data.is_empty():
             self.node.shading = shading
+            self._on_camera_move()
         self.node.update()
 
     def _on_wireframe_visible_change(self):
@@ -158,11 +189,30 @@ class VispySurfaceLayer(VispyBaseLayer):
                 primitive='vertex',
             )
 
+    def _on_camera_move(self, event=None):
+        if (
+            event is not None
+            and event.type == 'angles'
+            and self.layer._slice_input.ndisplay == 3
+        ):
+            camera = event.source
+            # take displayed up and view directions and flip zyx for vispy
+            up = np.array(camera.up_direction)[::-1]
+            view = np.array(camera.view_direction)[::-1]
+            # combine to get light behind the camera on the top right
+            self._light_direction = view - up + np.cross(up, view)
+        if (
+            self.node.shading_filter is not None
+            and self._meshdata._vertices is not None
+        ):
+            self.node.shading_filter.light_dir = self._light_direction
+
     def reset(self, event=None):
         super().reset()
         self._on_colormap_change()
         self._on_contrast_limits_change()
         self._on_shading_change()
+        self._on_texture_change()
         self._on_wireframe_visible_change()
         self._on_wireframe_width_change()
         self._on_wireframe_color_change()
