@@ -1,3 +1,5 @@
+from typing import ClassVar
+
 from vispy.scene.visuals import Markers as BaseMarkers
 
 clamp_shader = """
@@ -13,7 +15,7 @@ new_vshader = old_vshader[:-2] + clamp_shader + '\n}'  # very ugly...
 
 
 class Markers(BaseMarkers):
-    _shaders = {
+    _shaders: ClassVar[dict[str, str]] = {
         'vertex': new_vshader,
         'fragment': BaseMarkers._shaders['fragment'],
     }
