@@ -156,9 +156,9 @@ def test_remove_selected():
 def test_remove_linked_layer():
     """Test removing a layer that is linked to other layers"""
     layers = LayerList()
-    layer_a = Image(np.empty((10, 10)))
-    layer_b = Image(np.empty((15, 15)))
-    layer_c = Image(np.empty((15, 15)))
+    layer_a = Image(np.random.random((10, 10)))
+    layer_b = Image(np.random.random((15, 15)))
+    layer_c = Image(np.random.random((15, 15)))
     layers.extend([layer_a, layer_b, layer_c])
 
     # link layer_c with layer_b
@@ -427,7 +427,10 @@ def test_layers_save_selected(builtins, tmpdir, layer_data_and_types):
 
 
 # the layers fixture is defined in napari/conftest.py
-@pytest.mark.filterwarnings('ignore:`np.int` is a deprecated alias for')
+# TODO: this warning filter can be removed when a new version
+# of napari-svg includes the following PR:
+# https://github.com/napari/napari-svg/pull/38
+@pytest.mark.filterwarnings('ignore:edge_:FutureWarning')
 def test_layers_save_svg(tmpdir, layers, napari_svg_name):
     """Test saving all layer data to an svg."""
     pm = npe2.PluginManager.instance()
@@ -447,12 +450,11 @@ def test_layers_save_svg(tmpdir, layers, napari_svg_name):
 
 def test_world_extent():
     """Test world extent after adding layers."""
-    np.random.seed(0)
     layers = LayerList()
 
     # Empty data is taken to be 512 x 512
-    np.testing.assert_allclose(layers.extent.world[0], (-0.5, -0.5))
-    np.testing.assert_allclose(layers.extent.world[1], (511.5, 511.5))
+    np.testing.assert_allclose(layers.extent.world[0], (0, 0))
+    np.testing.assert_allclose(layers.extent.world[1], (511, 511))
     np.testing.assert_allclose(layers.extent.step, (1, 1))
 
     # Add one layer
@@ -460,10 +462,10 @@ def test_world_extent():
         np.random.random((6, 10, 15)), scale=(3, 1, 1), translate=(10, 20, 5)
     )
     layers.append(layer_a)
-    np.testing.assert_allclose(layer_a.extent.world[0], (8.5, 19.5, 4.5))
-    np.testing.assert_allclose(layer_a.extent.world[1], (26.5, 29.5, 19.5))
-    np.testing.assert_allclose(layers.extent.world[0], (8.5, 19.5, 4.5))
-    np.testing.assert_allclose(layers.extent.world[1], (26.5, 29.5, 19.5))
+    np.testing.assert_allclose(layer_a.extent.world[0], (10, 20, 5))
+    np.testing.assert_allclose(layer_a.extent.world[1], (25, 29, 19))
+    np.testing.assert_allclose(layers.extent.world[0], (10, 20, 5))
+    np.testing.assert_allclose(layers.extent.world[1], (25, 29, 19))
     np.testing.assert_allclose(layers.extent.step, (3, 1, 1))
 
     # Add another layer
@@ -471,33 +473,28 @@ def test_world_extent():
         np.random.random((8, 6, 15)), scale=(6, 2, 1), translate=(-5, -10, 10)
     )
     layers.append(layer_b)
-    np.testing.assert_allclose(layer_b.extent.world[0], (-8, -11, 9.5))
-    np.testing.assert_allclose(layer_b.extent.world[1], (40, 1, 24.5))
-    np.testing.assert_allclose(layers.extent.world[0], (-8, -11, 4.5))
-    np.testing.assert_allclose(layers.extent.world[1], (40, 29.5, 24.5))
+    np.testing.assert_allclose(layer_b.extent.world[0], (-5, -10, 10))
+    np.testing.assert_allclose(layer_b.extent.world[1], (37, 0, 24))
+    np.testing.assert_allclose(layers.extent.world[0], (-5, -10, 5))
+    np.testing.assert_allclose(layers.extent.world[1], (37, 29, 24))
     np.testing.assert_allclose(layers.extent.step, (3, 1, 1))
 
 
 def test_world_extent_mixed_ndim():
     """Test world extent after adding layers of different dimensionality."""
-    np.random.seed(0)
     layers = LayerList()
 
     # Add 3D layer
     layer_a = Image(np.random.random((15, 15, 15)), scale=(4, 12, 2))
     layers.append(layer_a)
-    np.testing.assert_allclose(layers.extent.world[1], (58, 174, 29))
-    np.testing.assert_allclose(
-        layers.extent.world[1] - layers.extent.world[0], (60, 180, 30)
-    )
+    np.testing.assert_allclose(layers.extent.world[0], (0, 0, 0))
+    np.testing.assert_allclose(layers.extent.world[1], (56, 168, 28))
 
     # Add 2D layer
     layer_b = Image(np.random.random((10, 10)), scale=(6, 4))
     layers.append(layer_b)
-    np.testing.assert_allclose(layers.extent.world[1], (58, 174, 38))
-    np.testing.assert_allclose(
-        layers.extent.world[1] - layers.extent.world[0], (60, 180, 40)
-    )
+    np.testing.assert_allclose(layers.extent.world[0], (0, 0, 0))
+    np.testing.assert_allclose(layers.extent.world[1], (56, 168, 36))
     np.testing.assert_allclose(layers.extent.step, (4, 6, 2))
 
 
@@ -506,20 +503,18 @@ def test_world_extent_mixed_flipped():
     # Flipped data results in a negative scale value which should be
     # made positive when taking into consideration for the step size
     # calculation
-    np.random.seed(0)
     layers = LayerList()
 
     layer = Image(
         np.random.random((15, 15)), affine=[[0, 1, 0], [1, 0, 0], [0, 0, 1]]
     )
     layers.append(layer)
-    np.testing.assert_allclose(layer._data_to_world.scale, (1, -1))
+    np.testing.assert_allclose(layer._data_to_world.scale, (1, 1))
     np.testing.assert_allclose(layers.extent.step, (1, 1))
 
 
 def test_ndim():
     """Test world extent after adding layers."""
-    np.random.seed(0)
     layers = LayerList()
 
     assert layers.ndim == 2
@@ -541,9 +536,9 @@ def test_ndim():
 
 def test_name_uniqueness():
     layers = LayerList()
-    layers.append(Image(np.random.random((10, 15)), name="Image [1]"))
-    layers.append(Image(np.random.random((10, 15)), name="Image"))
-    layers.append(Image(np.random.random((10, 15)), name="Image"))
+    layers.append(Image(np.random.random((10, 15)), name='Image [1]'))
+    layers.append(Image(np.random.random((10, 15)), name='Image'))
+    layers.append(Image(np.random.random((10, 15)), name='Image'))
     assert [x.name for x in layers] == ['Image [1]', 'Image', 'Image [2]']
 
 
@@ -551,20 +546,20 @@ def test_readd_layers():
     layers = LayerList()
     imgs = []
     for _i in range(5):
-        img = Image(np.random.rand(10, 10, 10))
+        img = Image(np.random.random((10, 10, 10)))
         layers.append(img)
         imgs.append(img)
 
     assert layers == imgs
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='already present'):
         layers.append(imgs[1])
     assert layers == imgs
 
     layers[1] = layers[1]
     assert layers == imgs
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='already present'):
         layers[1] = layers[2]
     assert layers == imgs
 
@@ -575,6 +570,6 @@ def test_readd_layers():
     layers[:3] = layers[2::-1]
     assert set(layers) == set(imgs)
 
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='already present'):
         layers[:3] = layers[:]
     assert set(layers) == set(imgs)
