@@ -18,8 +18,8 @@ two_colormaps = MAGENTA_GREEN
 green_cmap = SIMPLE_COLORMAPS['green']
 red_cmap = SIMPLE_COLORMAPS['red']
 blue_cmap = AVAILABLE_COLORMAPS['blue']
-cmap_tuple = ("my_colormap", Colormap(['g', 'm', 'y']))
-cmap_dict = {"your_colormap": Colormap(['g', 'r', 'y'])}
+cmap_tuple = ('my_colormap', Colormap(['g', 'm', 'y']))
+cmap_dict = {'your_colormap': Colormap(['g', 'r', 'y'])}
 
 MULTI_TUPLES = [[0.3, 0.7], [0.1, 0.9], [0.3, 0.9], [0.4, 0.9], [0.2, 0.9]]
 
@@ -37,7 +37,7 @@ multi_channel_test_data = [
     # split single RGB image
     ((15, 10, 3), {'colormap': ['red', 'green', 'blue']}),
     # multiple RGB images
-    ((15, 10, 5, 3), {'channel_axis': 2, 'rgb': True}),
+    ((45, 40, 5, 3), {'channel_axis': 2, 'rgb': True}),
     # Test adding multichannel image with custom names.
     ((), {'name': ['multi ' + str(i + 3) for i in range(5)]}),
     # Test adding multichannel image with custom contrast limits.
@@ -94,7 +94,7 @@ ids = [
 ]
 
 
-@pytest.mark.parametrize('shape, kwargs', multi_channel_test_data, ids=ids)
+@pytest.mark.parametrize(('shape', 'kwargs'), multi_channel_test_data, ids=ids)
 def test_multichannel(shape, kwargs):
     """Test adding multichannel image."""
     viewer = ViewerModel()
@@ -109,7 +109,9 @@ def test_multichannel(shape, kwargs):
 
     for i in range(n_channels):
         # make sure that the data has been divided into layers
-        assert np.all(viewer.layers[i].data == data.take(i, axis=channel_axis))
+        np.testing.assert_array_equal(
+            viewer.layers[i].data, data.take(i, axis=channel_axis)
+        )
         # make sure colors have been assigned properly
         if 'colormap' not in kwargs:
             if n_channels == 1:
@@ -169,7 +171,7 @@ def test_multichannel_multiscale():
     for i in range(data[0].shape[-1]):
         assert np.all(
             [
-                np.all(l_d == d)
+                np.array_equal(l_d, d)
                 for l_d, d in zip(
                     viewer.layers[i].data,
                     [data[j].take(i, axis=-1) for j in range(len(data))],
@@ -191,7 +193,7 @@ def test_multichannel_implicit_multiscale():
     for i in range(data[0].shape[-1]):
         assert np.all(
             [
-                np.all(l_d == d)
+                np.array_equal(l_d, d)
                 for l_d, d in zip(
                     viewer.layers[i].data,
                     [data[j].take(i, axis=-1) for j in range(len(data))],
@@ -231,6 +233,6 @@ def test_multichannel_index_error_hint():
     with pytest.raises(IndexError) as e:
         viewer.add_image(data, channel_axis=0, name=['a', 'b'])
     assert (
-        "Requested channel_axis (0) had length 5, but the "
+        'Requested channel_axis (0) had length 5, but the '
         "'name' argument only provided 2 values." in str(e)
     )
