@@ -1,3 +1,5 @@
+import warnings
+
 import numpy as np
 import pytest
 
@@ -11,9 +13,9 @@ def test_translated_images():
     data = np.random.random((10, 10, 10))
     viewer.add_image(data)
     viewer.add_image(data, translate=[10, 0, 0])
-    assert viewer.dims.range[0] == (0, 20, 1)
-    assert viewer.dims.range[1] == (0, 10, 1)
-    assert viewer.dims.range[2] == (0, 10, 1)
+    assert viewer.dims.range[0] == (0, 19, 1)
+    assert viewer.dims.range[1] == (0, 9, 1)
+    assert viewer.dims.range[2] == (0, 9, 1)
     assert viewer.dims.nsteps == (20, 10, 10)
     for i in range(viewer.dims.nsteps[0]):
         viewer.dims.set_current_step(0, i)
@@ -27,13 +29,10 @@ def test_scaled_images():
     data = np.random.random((10, 10, 10))
     viewer.add_image(data)
     viewer.add_image(data[::2], scale=[2, 1, 1])
-    assert viewer.dims.range[0] == (
-        -0.5,
-        10,
-        1,
-    )  # TODO: non-integer with mixed scale?
-    assert viewer.dims.range[1] == (0, 10, 1)
-    assert viewer.dims.range[2] == (0, 10, 1)
+    # TODO: non-integer with mixed scale?
+    assert viewer.dims.range[0] == (0, 9, 1)
+    assert viewer.dims.range[1] == (0, 9, 1)
+    assert viewer.dims.range[2] == (0, 9, 1)
     assert viewer.dims.nsteps == (10, 10, 10)
     for i in range(viewer.dims.nsteps[0]):
         viewer.dims.set_current_step(0, i)
@@ -47,13 +46,10 @@ def test_scaled_and_translated_images():
     data = np.random.random((10, 10, 10))
     viewer.add_image(data)
     viewer.add_image(data[::2], scale=[2, 1, 1], translate=[10, 0, 0])
-    assert viewer.dims.range[0] == (
-        0,
-        19.5,
-        1,
-    )  # TODO: non-integer with mixed scale?
-    assert viewer.dims.range[1] == (0, 10, 1)
-    assert viewer.dims.range[2] == (0, 10, 1)
+    # TODO: non-integer with mixed scale?
+    assert viewer.dims.range[0] == (0, 18, 1)
+    assert viewer.dims.range[1] == (0, 9, 1)
+    assert viewer.dims.range[2] == (0, 9, 1)
     assert viewer.dims.nsteps == (19, 10, 10)
     for i in range(viewer.dims.nsteps[0]):
         viewer.dims.set_current_step(0, i)
@@ -67,9 +63,9 @@ def test_both_scaled_and_translated_images():
     data = np.random.random((10, 10, 10))
     viewer.add_image(data, scale=[2, 1, 1])
     viewer.add_image(data, scale=[2, 1, 1], translate=[20, 0, 0])
-    assert viewer.dims.range[0] == (0, 40, 2)
-    assert viewer.dims.range[1] == (0, 10, 1)
-    assert viewer.dims.range[2] == (0, 10, 1)
+    assert viewer.dims.range[0] == (0, 38, 2)
+    assert viewer.dims.range[1] == (0, 9, 1)
+    assert viewer.dims.range[2] == (0, 9, 1)
     assert viewer.dims.nsteps == (20, 10, 10)
     for i in range(viewer.dims.nsteps[0]):
         viewer.dims.set_current_step(0, i)
@@ -82,7 +78,7 @@ def test_no_warning_non_affine_slicing():
     np.random.seed(0)
     data = np.random.random((10, 10, 10))
     viewer.add_image(data, scale=[2, 1, 1], translate=[10, 15, 20])
-    with pytest.warns(None) as recorded_warnings:
+    with warnings.catch_warnings(record=True) as recorded_warnings:
         viewer.layers[0].refresh()
     assert len(recorded_warnings) == 0
 
@@ -97,10 +93,9 @@ def test_warning_affine_slicing():
             data,
             scale=[2, 1, 1],
             translate=[10, 15, 20],
-            shear=[[1, 0, 0], [0, 1, 0], [10, 0, 1]],
+            shear=[[1, 0, 0], [0, 1, 0], [4, 0, 1]],
         )
     assert 'Non-orthogonal slicing is being requested' in str(wrn[0].message)
     with pytest.warns(UserWarning) as recorded_warnings:
         viewer.layers[0].refresh()
-    # note right now refresh tiggers two `_slice_indices` calls
-    assert len(recorded_warnings) == 2
+    assert len(recorded_warnings) == 1
