@@ -1,7 +1,7 @@
-from typing import Optional, Tuple
+from typing import Optional
 
-from ..utils.events import EventedModel
-from ._viewer_constants import CursorStyle
+from napari.components._viewer_constants import CursorStyle
+from napari.utils.events import EventedModel
 
 
 class Cursor(EventedModel):
@@ -17,7 +17,7 @@ class Cursor(EventedModel):
         Only relevant for circle and square cursors which are drawn
         with a particular size.
     size : float
-        Size of the cursor in canvas pixels.Only relevant for circle
+        Size of the cursor in canvas pixels. Only relevant for circle
         and square cursors which are drawn with a particular size.
     style : str
         Style of the cursor. Must be one of
@@ -28,14 +28,14 @@ class Cursor(EventedModel):
             * pointing: A finger for pointing
             * standard: The standard cursor
             # crosshair: A crosshair
-    _view_direction : Optional[Tuple[float, ...]]
+    _view_direction : Optional[Tuple[float, float, float]]
         The vector describing the direction of the camera in the scene.
         This is None when viewing in 2D.
     """
 
     # fields
-    position: Tuple[float, ...] = (1, 1)
+    position: tuple[float, ...] = (1, 1)
     scaled: bool = True
-    size: int = 1
+    size = 1.0
     style: CursorStyle = CursorStyle.STANDARD
-    _view_direction: Optional[Tuple[float, ...]] = None
+    _view_direction: Optional[tuple[float, float, float]] = None
