@@ -5,17 +5,17 @@ for having a wrapper class is that so the rest of napari does not
 need to import any multiprocessing code unless actually using
 the monitor.
 """
+
 import errno
 import json
 import logging
 import os
-import sys
 from pathlib import Path
 from typing import Optional
 
-from ....utils.translations import trans
+from napari.utils.translations import trans
 
-LOGGER = logging.getLogger("napari.monitor")
+LOGGER = logging.getLogger('napari.monitor')
 
 # If False monitor is disabled even if we meet all other requirements.
 ENABLE_MONITOR = True
@@ -39,7 +39,7 @@ def _load_config(path: str) -> dict:
         raise FileNotFoundError(
             errno.ENOENT,
             trans._(
-                "Monitor: Config file not found: {path}",
+                'Monitor: Config file not found: {path}',
                 deferred=True,
                 path=path,
             ),
@@ -59,8 +59,8 @@ def _load_monitor_config() -> Optional[dict]:
     """
     # We shouldn't even call into this file unless NAPARI_MON is defined
     # but check to be sure.
-    value = os.getenv("NAPARI_MON")
-    if value in [None, "0"]:
+    value = os.getenv('NAPARI_MON')
+    if value in [None, '0']:
         return None
 
     return _load_config(value)
@@ -85,7 +85,7 @@ def _setup_logging(config: dict) -> None:
     fh = logging.FileHandler(log_path)
     LOGGER.addHandler(fh)
     LOGGER.setLevel(logging.DEBUG)
-    LOGGER.info("Writing to log path %s", log_path)
+    LOGGER.info('Writing to log path %s', log_path)
 
 
 def _get_monitor_config() -> Optional[dict]:
@@ -102,23 +102,16 @@ def _get_monitor_config() -> Optional[dict]:
     Optional[dict]
         The configuration for the MonitorService.
     """
-    if sys.version_info[:2] < (3, 9):
-        # We require Python 3.9 for now. The shared memory features we need
-        # were added in 3.8, but the 3.8 implemention was buggy. It's
-        # possible we could backport to or otherwise fix 3.8 or even 3.7,
-        # but for now we're making 3.9 a requirement.
-        print("Monitor: not starting, requires Python 3.9 or newer")
-        return None
 
     if not ENABLE_MONITOR:
-        print("Monitor: not starting, disabled")
+        logging.warning('Monitor: not starting, disabled')
         return None
 
     # The NAPARI_MON environment variable points to our config file.
     config = _load_monitor_config()
 
     if config is None:
-        print("Monitor: not starting, no usable config file")
+        logging.warning('Monitor: not starting, no usable config file')
         return None
 
     return config
@@ -134,7 +127,7 @@ class Monitor:
     process has fully started.
     """
 
-    def __init__(self):
+    def __init__(self) -> None:
         # Both are set when start() is called, and only if we have
         # a parseable config file, have Python 3.9, etc.
         self._service = None
@@ -176,8 +169,10 @@ class Monitor:
 
         # Late imports so no multiprocessing modules are even
         # imported unless we are going to start the service.
-        from ._api import MonitorApi
-        from ._service import MonitorService
+        from napari.components.experimental.monitor._api import MonitorApi
+        from napari.components.experimental.monitor._service import (
+            MonitorService,
+        )
 
         # Create the API first. It will register our callbacks, then
         # we start the manager that will serve those callbacks.
@@ -202,7 +197,7 @@ class Monitor:
 
         self._running = False
 
-    def on_poll(self, event=None) -> None:
+    def on_poll(self, event) -> None:
         """The QtPoll object polls us.
 
         Probably we could get rid of polling by creating a thread that
