@@ -1,21 +1,29 @@
+from __future__ import annotations
+
 import itertools
+import typing
 import warnings
-from collections import namedtuple
+from collections.abc import Iterable
 from functools import cached_property
-from typing import TYPE_CHECKING, Iterable, List, Optional, Tuple, Union
+from typing import TYPE_CHECKING, Optional, Union
 
 import numpy as np
 
+from napari.components.dims import RangeTuple
 from napari.layers import Layer
-from napari.layers.image.image import _ImageBase
+from napari.layers.utils.layer_utils import Extent
 from napari.utils.events.containers import SelectableEventedList
 from napari.utils.naming import inc_name_count
 from napari.utils.translations import trans
 
-Extent = namedtuple('Extent', 'data world step')
-
 if TYPE_CHECKING:
     from npe2.manifest.io import WriterContribution
+    from typing_extensions import Self
+
+
+def get_name(layer: Layer) -> str:
+    """Return the name of a layer."""
+    return layer.name
 
 
 class LayerList(SelectableEventedList[Layer]):
@@ -60,49 +68,52 @@ class LayerList(SelectableEventedList[Layer]):
         super().__init__(
             data=data,
             basetype=Layer,
-            lookup={str: lambda e: e.name},
+            lookup={str: get_name},
         )
+        self._create_contexts()
+
+    def _create_contexts(self):
+        """Create contexts to manage enabled/visible action/menu states.
+
+        Connects LayerList and Selection[Layer] to their context keys to allow
+        actions and menu items (in the GUI) to be dynamically enabled/disabled
+        and visible/hidden based on the state of layers in the list.
+        """
 
         # TODO: figure out how to move this context creation bit.
         # Ideally, the app should be aware of the layerlist, but not vice versa.
-        # This could probably be done by having the layerlist emit events that the app
-        # connects to, then the `_ctx` object would live on the app, (not here)
+        # This could probably be done by having the layerlist emit events that
+        # the app connects to, then the `_ctx` object would live on the app,
+        # (not here)
         from napari._app_model.context import create_context
         from napari._app_model.context._layerlist_context import (
             LayerListContextKeys,
+            LayerListSelectionContextKeys,
         )
 
         self._ctx = create_context(self)
         if self._ctx is not None:  # happens during Viewer type creation
             self._ctx_keys = LayerListContextKeys(self._ctx)
+            self.events.inserted.connect(self._ctx_keys.update)
+            self.events.removed.connect(self._ctx_keys.update)
 
-            self.selection.events.changed.connect(self._ctx_keys.update)
-
-        # temporary: see note in _on_selection_event
-        self.selection.events.changed.connect(self._on_selection_changed)
-
-    def _on_selection_changed(self, event):
-        # This method is a temporary workaround to the fact that the Points
-        # layer needs to know when its selection state changes so that it can
-        # update the highlight state.  This (and the layer._on_selection
-        # method) can be removed once highlighting logic has been removed from
-        # the layer model.
-        for layer in event.added:
-            layer._on_selection(True)
-        for layer in event.removed:
-            layer._on_selection(False)
+            self._selection_ctx_keys = LayerListSelectionContextKeys(self._ctx)
+            self.selection.events.changed.connect(
+                self._selection_ctx_keys.update
+            )
 
     def _process_delete_item(self, item: Layer):
         super()._process_delete_item(item)
         item.events.extent.disconnect(self._clean_cache)
+        item.events._extent_augmented.disconnect(self._clean_cache)
         self._clean_cache()
 
     def _clean_cache(self):
         cached_properties = (
             'extent',
             '_extent_world',
+            '_extent_world_augmented',
             '_step_size',
-            '_ranges',
         )
         [self.__dict__.pop(p, None) for p in cached_properties]
 
@@ -149,6 +160,15 @@ class LayerList(SelectableEventedList[Layer]):
                 )
         return values
 
+    @typing.overload
+    def __getitem__(self, item: Union[int, str]) -> Layer: ...
+
+    @typing.overload
+    def __getitem__(self, item: slice) -> Self: ...
+
+    def __getitem__(self, item):
+        return super().__getitem__(item)
+
     def __setitem__(self, key, value):
         old = self._list[key]
         if isinstance(key, slice):
@@ -164,6 +184,7 @@ class LayerList(SelectableEventedList[Layer]):
         new_layer.name = self._coerce_name(new_layer.name)
         self._clean_cache()
         new_layer.events.extent.connect(self._clean_cache)
+        new_layer.events._extent_augmented.connect(self._clean_cache)
         super().insert(index, new_layer)
 
     def remove_selected(self):
@@ -191,6 +212,22 @@ class LayerList(SelectableEventedList[Layer]):
         """
         return self._get_extent_world([layer.extent for layer in self])
 
+    @cached_property
+    def _extent_world_augmented(self) -> np.ndarray:
+        """Extent of layers in world coordinates.
+
+        Default to 2D with (-0.5, 511.5) min/ max values if no data is present.
+        Corresponds to pixels centered at [0, ..., 511].
+
+        Returns
+        -------
+        extent_world : array, shape (2, D)
+        """
+        return self._get_extent_world(
+            [layer._extent_augmented for layer in self],
+            augmented=True,
+        )
+
     def _get_min_and_max(self, mins_list, maxes_list):
         # Reverse dimensions since it is the last dimensions that are
         # displayed.
@@ -225,19 +262,23 @@ class LayerList(SelectableEventedList[Layer]):
         # switch back to original order
         return min_v[::-1], max_v[::-1]
 
-    def _get_extent_world(self, layer_extent_list):
+    def _get_extent_world(self, layer_extent_list, augmented=False):
         """Extent of layers in world coordinates.
 
-        Default to 2D with (-0.5, 511.5) min/ max values if no data is present.
-        Corresponds to pixels centered at [0, ..., 511].
+        Default to 2D image-like with (0, 511) min/ max values if no data is present.
+        Corresponds to image with 512 pixels in each dimension.
 
         Returns
         -------
         extent_world : array, shape (2, D)
         """
         if len(self) == 0:
-            min_v = np.asarray([-0.5] * self.ndim)
-            max_v = np.asarray([511.5] * self.ndim)
+            min_v = np.zeros(self.ndim)
+            max_v = np.full(self.ndim, 511.0)
+            # image-like augmented extent is actually expanded by 0.5
+            if augmented:
+                min_v -= 0.5
+                max_v += 0.5
         else:
             extrema = [extent.world for extent in layer_extent_list]
             mins = [e[0] for e in extrema]
@@ -279,8 +320,9 @@ class LayerList(SelectableEventedList[Layer]):
     def get_extent(self, layers: Iterable[Layer]) -> Extent:
         """
         Return extent for a given layer list.
-        This function is useful for calculating the extent of a subset of layers
-        when preparing and updating some supplementary layers.
+
+        Extent bounds are inclusive. This function is useful for calculating the extent
+        of a subset of layers when preparing and updating some supplementary layers.
         For example see the cross Vectors layer in the `multiple_viewer_widget` example.
 
         Parameters
@@ -291,7 +333,7 @@ class LayerList(SelectableEventedList[Layer]):
         Returns
         -------
         extent : Extent
-             extent for selected layers
+            extent for selected layers
         """
         extent_list = [layer.extent for layer in layers]
         return Extent(
@@ -302,57 +344,21 @@ class LayerList(SelectableEventedList[Layer]):
 
     @cached_property
     def extent(self) -> Extent:
-        """Extent of layers in data and world coordinates."""
+        """
+        Extent of layers in data and world coordinates.
+
+        Extent bounds are inclusive. See Layer.extent for a detailed explanation
+        of how extents are calculated.
+        """
         return self.get_extent(list(self))
 
-    @cached_property
-    def _ranges(self) -> List[Tuple[float, float, float]]:
-        """Get ranges for Dims.range in world coordinates.
-
-        This shares some code in common with the `extent` property, but
-        determines Dims.range settings for each dimension such that each
-        range is aligned to pixel centers at the finest scale.
-        """
-        if len(self) == 0:
-            return [(0, 1, 1)] * self.ndim
-
-        # Determine minimum step size across all layers
-        layer_extent_list = [layer.extent for layer in self]
-        scales = [extent.step for extent in layer_extent_list]
-        min_steps = self._step_size_from_scales(scales)
-
-        # Pixel-based layers need to be offset by 0.5 * min_steps to align
-        # Dims.range with pixel centers in world coordinates
-        pixel_offsets = [
-            0.5 * min_steps
-            if isinstance(layer, _ImageBase)
-            else [0] * len(min_steps)
-            for layer in self
-        ]
-
-        # Non-pixel layers need an offset of the range stop by min_steps since the upper
-        # limit of Dims.range is non-inclusive.
-        point_offsets = [
-            [0] * len(min_steps)
-            if isinstance(layer, _ImageBase)
-            else min_steps
-            for layer in self
-        ]
-
-        # Determine world coordinate extents similarly to
-        # `_get_extent_world`, but including offsets calculated above.
-        extrema = [extent.world for extent in layer_extent_list]
-        mins = [
-            e[0] + o1[: len(e[0])] for e, o1 in zip(extrema, pixel_offsets)
-        ]
-        maxs = [
-            e[1] + o1[: len(e[0])] + o2[: len(e[0])]
-            for e, o1, o2 in zip(extrema, pixel_offsets, point_offsets)
-        ]
-        min_v, max_v = self._get_min_and_max(mins, maxs)
-
-        # form range tuples, switching back to original dimension order
-        return list(zip(min_v, max_v, min_steps))
+    @property
+    def _ranges(self) -> tuple[RangeTuple, ...]:
+        """Get ranges for Dims.range in world coordinates."""
+        ext = self.extent
+        return tuple(
+            RangeTuple(*x) for x in zip(ext.world[0], ext.world[1], ext.step)
+        )
 
     @property
     def ndim(self) -> int:
@@ -404,8 +410,8 @@ class LayerList(SelectableEventedList[Layer]):
         *,
         selected: bool = False,
         plugin: Optional[str] = None,
-        _writer: Optional['WriterContribution'] = None,
-    ) -> List[str]:
+        _writer: Optional[WriterContribution] = None,
+    ) -> list[str]:
         """Save all or only selected layers to a path using writer plugins.
 
         If ``plugin`` is not provided and only one layer is targeted, then we
@@ -469,9 +475,9 @@ class LayerList(SelectableEventedList[Layer]):
         )
 
         if selected:
-            msg = trans._("No layers selected", deferred=True)
+            msg = trans._('No layers selected', deferred=True)
         else:
-            msg = trans._("No layers to save", deferred=True)
+            msg = trans._('No layers to save', deferred=True)
 
         if not layers:
             warnings.warn(msg)
