@@ -1,3 +1,5 @@
+from typing import Union
+
 from napari.components._viewer_constants import CanvasPosition
 from napari.layers.base._base_constants import Blending
 from napari.utils.events import EventedModel
@@ -23,7 +25,7 @@ class Overlay(EventedModel):
 
     visible: bool = False
     opacity: float = 1
-    order: int = 1e6
+    order: int = 10**6
     blending: Blending
 
     def __hash__(self):
@@ -49,7 +51,9 @@ class CanvasOverlay(Overlay):
         The rendering order of the overlay: lower numbers get rendered first.
     """
 
-    position: CanvasPosition = CanvasPosition.BOTTOM_RIGHT
+    position: Union[CanvasPosition, tuple[int, int]] = (
+        CanvasPosition.BOTTOM_RIGHT
+    )
     blending: Blending = Blending.TRANSLUCENT_NO_DEPTH
 
 
