@@ -208,11 +208,18 @@ def _fresh_settings(monkeypatch):
     """
     from napari import settings
     from napari.settings import NapariSettings
+    from napari.settings._experimental import ExperimentalSettings
 
     # prevent the developer's config file from being used if it exists
     cp = NapariSettings.__private_attributes__['_config_path']
     monkeypatch.setattr(cp, 'default', None)
 
+    monkeypatch.setattr(
+        ExperimentalSettings.__fields__['compiled_triangulation'],
+        'default',
+        True,
+    )
+
     # calling save() with no config path is normally an error
     # here we just have save() return if called without a valid path
     NapariSettings.__original_save__ = NapariSettings.save
@@ -224,8 +231,8 @@ def _fresh_settings(monkeypatch):
 
     monkeypatch.setattr(NapariSettings, 'save', _mock_save)
 
-    # this makes sure that we start with fresh settings for every test.
     settings._SETTINGS = None
+    # this makes sure that we start with fresh settings for every test.
     return
 
 
@@ -431,13 +438,13 @@ def _event_check(instance):
     def _prepare_check(name, no_event_):
         def check(instance, no_event=no_event_):
             if name in no_event:
-                assert not hasattr(
-                    instance.events, name
-                ), f'event {name} defined'
+                assert not hasattr(instance.events, name), (
+                    f'event {name} defined'
+                )
             else:
-                assert hasattr(
-                    instance.events, name
-                ), f'event {name} not defined'
+                assert hasattr(instance.events, name), (
+                    f'event {name} not defined'
+                )
 
         return check
 
