@@ -1,10 +1,12 @@
 from __future__ import annotations
 
-from typing import List, Sequence, Tuple, Union
+from collections.abc import Sequence
+from typing import Union
 
 import numpy as np
 
-from ._data_protocols import LayerDataProtocol, assert_protocol
+from napari.layers._data_protocols import LayerDataProtocol, assert_protocol
+from napari.utils.translations import trans
 
 
 # note: this also implements `LayerDataProtocol`, but we don't need to inherit.
@@ -34,29 +36,41 @@ class MultiScaleData(Sequence[LayerDataProtocol]):
         self,
         data: Sequence[LayerDataProtocol],
     ) -> None:
-        self._data: List[LayerDataProtocol] = list(data)
+        self._data: list[LayerDataProtocol] = list(data)
         if not self._data:
-            raise ValueError("Multiscale data must be a (non-empty) sequence")
+            raise ValueError(
+                trans._('Multiscale data must be a (non-empty) sequence')
+            )
         for d in self._data:
             assert_protocol(d)
 
+    @property
+    def size(self) -> int:
+        """Return size of the first scale.."""
+        return self._data[0].size
+
+    @property
+    def ndim(self) -> int:
+        """Return ndim of the first scale.."""
+        return self._data[0].ndim
+
     @property
     def dtype(self) -> np.dtype:
         """Return dtype of the first scale.."""
         return self._data[0].dtype
 
     @property
-    def shape(self) -> Tuple[int, ...]:
+    def shape(self) -> tuple[int, ...]:
         """Shape of multiscale is just the biggest shape."""
         return self._data[0].shape
 
     @property
-    def shapes(self) -> Tuple[Tuple[int, ...], ...]:
+    def shapes(self) -> tuple[tuple[int, ...], ...]:
         """Tuple shapes for all scales."""
         return tuple(im.shape for im in self._data)
 
     def __getitem__(  # type: ignore [override]
-        self, key: Union[int, Tuple[slice, ...]]
+        self, key: Union[int, tuple[slice, ...]]
     ) -> LayerDataProtocol:
         """Multiscale indexing."""
         return self._data[key]
@@ -81,6 +95,6 @@ class MultiScaleData(Sequence[LayerDataProtocol]):
 
     def __repr__(self) -> str:
         return (
-            f"<MultiScaleData at {hex(id(self))}. "
+            f'<MultiScaleData at {hex(id(self))}. '
             f"{len(self)} levels, '{self.dtype}', shapes: {self.shapes}>"
         )
