@@ -678,6 +678,22 @@ class Layer(KeymapProvider, MousemapProvider, ABC, metaclass=PostInit):
     def source(self) -> Source:
         return self._source
 
+    def _set_source(self, source: Source) -> None:
+        if any(
+            getattr(self._source, attr)
+            for attr in [
+                'path',
+                'reader_plugin',
+                'sample',
+                'widget',
+                'parent',
+            ]
+        ):
+            raise ValueError(
+                f'Tried to set source on layer {self.name} when source is already set to {self._source}'
+            )
+        self._source = source
+
     @property
     def loaded(self) -> bool:
         """True if this layer is fully loaded in memory, False otherwise.
