@@ -1,18 +1,22 @@
-"""guess_rgb, guess_multiscale, guess_labels.
-"""
-from typing import Tuple
+"""guess_rgb, guess_multiscale, guess_labels."""
+
+from collections.abc import Sequence
+from typing import Any, Callable, Literal, Union
 
 import numpy as np
+import numpy.typing as npt
 
 from napari.layers._data_protocols import LayerDataProtocol
 from napari.layers._multiscale_data import MultiScaleData
+from napari.layers.image._image_constants import ImageProjectionMode
 from napari.utils.translations import trans
 
 
-def guess_rgb(shape):
+def guess_rgb(shape: tuple[int, ...], min_side_len: int = 30) -> bool:
     """Guess if the passed shape comes from rgb data.
 
-    If last dim is 3 or 4 assume the data is rgb, including rgba.
+    If last dim is 3 or 4 and other dims are larger (>30), assume the data is
+    rgb, including rgba.
 
     Parameters
     ----------
@@ -26,11 +30,18 @@ def guess_rgb(shape):
     """
     ndim = len(shape)
     last_dim = shape[-1]
+    viewed_dims = shape[-3:-1]
 
-    return ndim > 2 and last_dim in (3, 4)
+    return (
+        ndim > 2
+        and last_dim in (3, 4)
+        and all(d > min_side_len for d in viewed_dims)
+    )
 
 
-def guess_multiscale(data) -> Tuple[bool, LayerDataProtocol]:
+def guess_multiscale(
+    data: Union[MultiScaleData, list, tuple],
+) -> tuple[bool, Union[LayerDataProtocol, Sequence[LayerDataProtocol]]]:
     """Guess whether the passed data is multiscale, process it accordingly.
 
     If shape of arrays along first axis is strictly decreasing, the data is
@@ -91,7 +102,7 @@ def guess_multiscale(data) -> Tuple[bool, LayerDataProtocol]:
     return True, MultiScaleData(data)
 
 
-def guess_labels(data):
+def guess_labels(data: Any) -> Literal['labels', 'image']:
     """Guess if array contains labels data."""
 
     if hasattr(data, 'dtype') and data.dtype in (
@@ -103,3 +114,21 @@ def guess_labels(data):
         return 'labels'
 
     return 'image'
+
+
+def project_slice(
+    data: npt.NDArray, axis: tuple[int, ...], mode: ImageProjectionMode
+) -> npt.NDArray:
+    """Project a thick slice along axis based on mode."""
+    func: Callable
+    if mode == ImageProjectionMode.SUM:
+        func = np.sum
+    elif mode == ImageProjectionMode.MEAN:
+        func = np.mean
+    elif mode == ImageProjectionMode.MAX:
+        func = np.max
+    elif mode == ImageProjectionMode.MIN:
+        func = np.min
+    else:
+        raise NotImplementedError(f'unimplemented projection: {mode}')
+    return func(data, tuple(axis))
