@@ -27,9 +27,9 @@ def test_timing_fast_big_dask(data, kwargs):
     now = time.monotonic()
     assert Image(data, **kwargs).data.shape == data.shape
     elapsed = time.monotonic() - now
-    assert (
-        elapsed < 2
-    ), 'Test took to long some computation are likely not lazy'
+    assert elapsed < 2, (
+        'Test took to long some computation are likely not lazy'
+    )
 
 
 def test_non_visible_images():
