@@ -17,7 +17,9 @@ def test_random_multiscale():
     assert layer.data == data
     assert layer.multiscale is True
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -31,7 +33,9 @@ def test_infer_multiscale():
     assert layer.data == data
     assert layer.multiscale is True
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -45,7 +49,9 @@ def test_infer_tuple_multiscale():
     assert layer.data == data
     assert layer.multiscale is True
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -56,10 +62,10 @@ def test_blocking_multiscale():
     np.random.seed(0)
     data = np.random.random(shape)
     layer = Image(data, multiscale=False)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
     assert layer.multiscale is False
     assert layer.ndim == len(shape)
-    np.testing.assert_array_equal(layer.extent.data[1], shape)
+    np.testing.assert_array_equal(layer.extent.data[1], [s - 1 for s in shape])
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -80,7 +86,7 @@ def test_multiscale_tuple():
     assert layer.data == data
     assert layer.multiscale is True
     assert layer.ndim == len(shape)
-    np.testing.assert_array_equal(layer.extent.data[1], shape)
+    np.testing.assert_array_equal(layer.extent.data[1], [s - 1 for s in shape])
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -93,7 +99,9 @@ def test_3D_multiscale():
     layer = Image(data, multiscale=True)
     assert layer.data == data
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
@@ -106,46 +114,54 @@ def test_non_uniform_3D_multiscale():
     layer = Image(data, multiscale=True)
     assert layer.data == data
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
     assert layer._data_view.ndim == 2
 
 
 def test_rgb_multiscale():
     """Test instantiating Image layer with RGB data."""
-    shapes = [(40, 20, 3), (20, 10, 3), (10, 5, 3)]
+    shapes = [(40, 32, 3), (20, 16, 3), (10, 8, 3)]
     np.random.seed(0)
     data = [np.random.random(s) for s in shapes]
     layer = Image(data, multiscale=True)
     assert layer.data == data
     assert layer.ndim == len(shapes[0]) - 1
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0][:-1])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0][:-1]]
+    )
     assert layer.rgb is True
     assert layer._data_view.ndim == 3
 
 
 def test_3D_rgb_multiscale():
     """Test instantiating Image layer with 3D RGB data."""
-    shapes = [(8, 40, 20, 3), (4, 20, 10, 3), (2, 10, 5, 3)]
+    shapes = [(8, 40, 32, 3), (4, 20, 16, 3), (2, 10, 8, 3)]
     np.random.seed(0)
     data = [np.random.random(s) for s in shapes]
     layer = Image(data, multiscale=True)
     assert layer.data == data
     assert layer.ndim == len(shapes[0]) - 1
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0][:-1])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0][:-1]]
+    )
     assert layer.rgb is True
     assert layer._data_view.ndim == 3
 
 
 def test_non_rgb_image():
     """Test forcing Image layer to be 3D and not rgb."""
-    shapes = [(40, 20, 3), (20, 10, 3), (10, 5, 3)]
+    shapes = [(40, 32, 3), (20, 16, 3), (10, 8, 3)]
     np.random.seed(0)
     data = [np.random.random(s) for s in shapes]
     layer = Image(data, multiscale=True, rgb=False)
     assert layer.data == data
     assert layer.ndim == len(shapes[0])
-    np.testing.assert_array_equal(layer.extent.data[1], shapes[0])
+    np.testing.assert_array_equal(
+        layer.extent.data[1], [s - 1 for s in shapes[0]]
+    )
     assert layer.rgb is False
 
 
@@ -353,7 +369,9 @@ def test_corner_value():
     target_position = (39, 19)
     target_level = 0
     layer.data_level = target_level
-    layer.corner_pixels[1] = shapes[target_level]  # update requested view
+    layer.corner_pixels[1] = (
+        np.array(shapes[target_level]) - 1
+    )  # update requested view
     layer.refresh()
 
     # Test position at corner of image
@@ -393,7 +411,7 @@ def test_not_create_random_multiscale():
     np.random.seed(0)
     data = np.random.random(shape)
     layer = Image(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
     assert layer.multiscale is False
 
 
@@ -403,8 +421,8 @@ def test_world_data_extent():
     shapes = [(6, 40, 80), (3, 20, 40), (1, 10, 20)]
     data = [np.random.random(s) for s in shapes]
     layer = Image(data)
-    extent = np.array(((0,) * 3, shapes[0]))
-    check_layer_world_data_extent(layer, extent, (3, 1, 1), (10, 20, 5), True)
+    extent = np.array(((0,) * 3, [s - 1 for s in shapes[0]]))
+    check_layer_world_data_extent(layer, extent, (3, 1, 1), (10, 20, 5))
 
 
 def test_5D_multiscale():
@@ -437,13 +455,13 @@ def test_multiscale_data_protocol():
 
 @pytest.mark.parametrize(
     ('corner_pixels_world', 'exp_level', 'exp_corner_pixels_data'),
-    (
+    [
         ([[5, 5], [15, 15]], 0, [[5, 5], [15, 15]]),
         # Multiscale level selection uses > rather than >= so use -1 and 21
         # instead of 0 and 20 to ensure that the FOV is big enough.
-        ([[-1, -1], [21, 21]], 1, [[0, 0], [10, 10]]),
-        ([[-11, -11], [31, 31]], 2, [[0, 0], [5, 5]]),
-    ),
+        ([[-1, -1], [21, 21]], 1, [[0, 0], [9, 9]]),
+        ([[-11, -11], [31, 31]], 2, [[0, 0], [4, 4]]),
+    ],
 )
 def test_update_draw_variable_fov_fixed_canvas_size(
     corner_pixels_world, exp_level, exp_corner_pixels_data
@@ -465,11 +483,11 @@ def test_update_draw_variable_fov_fixed_canvas_size(
 
 @pytest.mark.parametrize(
     ('canvas_size_pixels', 'exp_level', 'exp_corner_pixels_data'),
-    (
-        ([16, 16], 0, [[0, 0], [20, 20]]),
-        ([8, 8], 1, [[0, 0], [10, 10]]),
-        ([4, 4], 2, [[0, 0], [5, 5]]),
-    ),
+    [
+        ([16, 16], 0, [[0, 0], [19, 19]]),
+        ([8, 8], 1, [[0, 0], [9, 9]]),
+        ([4, 4], 2, [[0, 0], [4, 4]]),
+    ],
 )
 def test_update_draw_variable_canvas_size_fixed_fov(
     canvas_size_pixels, exp_level, exp_corner_pixels_data
