@@ -1,16 +1,17 @@
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
 import numpy as np
 
-from ..utils.colormaps import ensure_colormap
-from ..utils.events import Event
-from ..utils.status_messages import format_float
-from ..utils.validators import validate_n_seq
+from napari.utils._dtype import normalize_dtype
+from napari.utils.colormaps import ensure_colormap
+from napari.utils.events import Event
+from napari.utils.status_messages import format_float
+from napari.utils.validators import _validate_increasing, validate_n_seq
 
 validate_2_tuple = validate_n_seq(2)
 
 if TYPE_CHECKING:
-    from .image.image import Image
+    from napari.layers._scalar_field.scalar_field import ScalarFieldBase
 
 
 class IntensityVisualizationMixin:
@@ -21,49 +22,67 @@ class IntensityVisualizationMixin:
         class Image(IntensityVisualizationMixin, Layer):
             def __init__(self):
                 ...
+
+    Note: `contrast_limits_range` is range extent available on the widget,
+    and `contrast_limits` is the visible range (the set values on the widget)
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
-        self.events.add(contrast_limits=Event, gamma=Event, colormap=Event)
+        self.events.add(
+            contrast_limits=Event,
+            contrast_limits_range=Event,
+            gamma=Event,
+            colormap=Event,
+        )
         self._gamma = 1
         self._colormap_name = ''
         self._contrast_limits_msg = ''
-        self._contrast_limits = [None, None]
-        self._contrast_limits_range = [None, None]
+        self._contrast_limits: tuple[Optional[float], Optional[float]] = (
+            None,
+            None,
+        )
+        self._contrast_limits_range: tuple[
+            Optional[float], Optional[float]
+        ] = (None, None)
         self._auto_contrast_source = 'slice'
         self._keep_auto_contrast = False
 
-    def reset_contrast_limits(self: 'Image', mode=None):
+    def reset_contrast_limits(self: 'ScalarFieldBase', mode=None):
         """Scale contrast limits to data range"""
         mode = mode or self._auto_contrast_source
         self.contrast_limits = self._calc_data_range(mode)
 
-    def reset_contrast_limits_range(self):
-        """Scale contrast limits range to data type.
+    def _calc_data_range(self, mode):
+        raise NotImplementedError
 
-        Currently, this only does something if the data type is an integer...
-        otherwise it's unclear what the full range should be.
+    def reset_contrast_limits_range(self, mode=None):
+        """Scale contrast limits range to data type if dtype is an integer,
+        or use the current maximum data range otherwise.
         """
-        if np.issubdtype(self.dtype, np.integer):
-            info = np.iinfo(self.dtype)
+        dtype = normalize_dtype(self.dtype)
+        if np.issubdtype(dtype, np.integer):
+            info = np.iinfo(dtype)
             self.contrast_limits_range = (info.min, info.max)
+        else:
+            mode = mode or self._auto_contrast_source
+            self.contrast_limits_range = self._calc_data_range(mode)
 
     @property
     def colormap(self):
         """napari.utils.Colormap: colormap for luminance images."""
         return self._colormap
 
+    @colormap.setter
+    def colormap(self, colormap):
+        self._set_colormap(colormap)
+
     def _set_colormap(self, colormap):
         self._colormap = ensure_colormap(colormap)
         self._update_thumbnail()
         self.events.colormap()
 
-    @colormap.setter
-    def colormap(self, colormap):
-        self._set_colormap(colormap)
-
     @property
     def colormaps(self):
         """tuple of str: names of available colormaps."""
@@ -77,6 +96,7 @@ class IntensityVisualizationMixin:
     @contrast_limits.setter
     def contrast_limits(self, contrast_limits):
         validate_2_tuple(contrast_limits)
+        _validate_increasing(contrast_limits)
         self._contrast_limits_msg = (
             format_float(contrast_limits[0])
             + ', '
@@ -98,8 +118,16 @@ class IntensityVisualizationMixin:
 
     @contrast_limits_range.setter
     def contrast_limits_range(self, value):
-        """Set the valid range of the contrast limits"""
+        """Set the valid range of the contrast limits.
+        If either value is "None", the current range will be preserved.
+        If the range overlaps the current contrast limits, the range will be set
+        requested and there will be no change the contrast limits.
+        If the requested contrast range limits are completely outside the
+        current contrast limits, the range will be set as requested and the
+        contrast limits will be reset to the new range.
+        """
         validate_2_tuple(value)
+        _validate_increasing(value)
         if list(value) == self.contrast_limits_range:
             return
 
@@ -109,16 +137,17 @@ class IntensityVisualizationMixin:
         for i in range(2):
             value[i] = current_range[i] if value[i] is None else value[i]
         self._contrast_limits_range = value
+        self.events.contrast_limits_range()
 
-        # make sure that the current values fit within the new range
+        # make sure that the contrast limits fit within the new range
         # this also serves the purpose of emitting events.contrast_limits()
         # and updating the views/controllers
         if hasattr(self, '_contrast_limits') and any(self._contrast_limits):
-            cur_min, cur_max = self.contrast_limits
-            new_min = min(max(value[0], cur_min), value[1])
-            new_max = max(min(value[1], cur_max), value[0])
-            self.contrast_limits = (new_min, new_max)
-            self.events.contrast_limits()
+            clipped_limits = np.clip(self.contrast_limits, *value)
+            if clipped_limits[0] < clipped_limits[1]:
+                self.contrast_limits = tuple(clipped_limits)
+            else:
+                self.contrast_limits = tuple(value)
 
     @property
     def gamma(self):
@@ -126,6 +155,6 @@ class IntensityVisualizationMixin:
 
     @gamma.setter
     def gamma(self, value):
-        self._gamma = value
+        self._gamma = float(value)
         self._update_thumbnail()
         self.events.gamma()
