@@ -1,3 +1,4 @@
+import typing
 import warnings
 from collections import deque
 from collections.abc import Sequence
@@ -211,6 +212,11 @@ class Labels(ScalarFieldBase):
         with a thickness equal to its value. Must be >= 0.
     brush_size : float
         Size of the paint brush in data coordinates.
+    iso_gradient_mode : str
+        Method for calulating the gradient (used to get the surface normal) in the
+        'iso_categorical' rendering mode. Must be one of {'fast', 'smooth'}.
+        'fast' uses a simple finite difference gradient in x, y, and z. 'smooth' uses an
+        isotropic Sobel gradient, which is smoother but more computationally expensive.
     selected_label : int
         Index of selected label. Can be greater than the current maximum label.
     mode : str
@@ -394,7 +400,7 @@ class Labels(ScalarFieldBase):
         self._contiguous = True
         self._brush_size = 10
 
-        self._iso_gradient_mode = IsoCategoricalGradientMode.FAST
+        self._iso_gradient_mode = IsoCategoricalGradientMode(iso_gradient_mode)
 
         self._selected_label = 1
         self.colormap.selection = self._selected_label
@@ -441,7 +447,7 @@ class Labels(ScalarFieldBase):
         self.events.rendering()
 
     @property
-    def iso_gradient_mode(self):
+    def iso_gradient_mode(self) -> str:
         """Return current gradient mode for isosurface rendering.
 
         Selects the finite-difference gradient method for the isosurface shader. Options include:
@@ -457,7 +463,7 @@ class Labels(ScalarFieldBase):
         return str(self._iso_gradient_mode)
 
     @iso_gradient_mode.setter
-    def iso_gradient_mode(self, value):
+    def iso_gradient_mode(self, value: Union[IsoCategoricalGradientMode, str]):
         self._iso_gradient_mode = IsoCategoricalGradientMode(value)
         self.events.iso_gradient_mode()
 
@@ -1566,7 +1572,9 @@ class Labels(ScalarFieldBase):
         if value is None:
             return []
 
-        label_value = value[1] if self.multiscale else value
+        label_value: int = typing.cast(
+            int, value[1] if self.multiscale else value
+        )
         if label_value not in self._label_index:
             return [trans._('[No Properties]')]
 
