@@ -1,8 +1,9 @@
 from collections import OrderedDict
-from enum import Enum, auto
+from enum import auto
+from typing import Union
 
-from ...utils.misc import StringEnum
-from ...utils.translations import trans
+from napari.utils.misc import StringEnum
+from napari.utils.translations import trans
 
 
 class ColorMode(StringEnum):
@@ -31,55 +32,45 @@ class Mode(StringEnum):
     SELECT allows the user to select points by clicking on them
     """
 
-    ADD = auto()
-    SELECT = auto()
     PAN_ZOOM = auto()
     TRANSFORM = auto()
+    ADD = auto()
+    SELECT = auto()
 
 
-class Symbol(Enum):
-    """Symbol: Valid symbol/marker types for the Points layer.
-    The string method returns the valid vispy string.
+class Symbol(StringEnum):
+    """Valid symbol/marker types for the Points layer."""
 
-    """
-
-    ARROW = 'arrow'
-    CLOBBER = 'clobber'
-    CROSS = 'cross'
-    DIAMOND = 'diamond'
-    DISC = 'disc'
-    HBAR = 'hbar'
-    RING = 'ring'
-    SQUARE = 'square'
-    STAR = 'star'
-    TAILED_ARROW = 'tailed_arrow'
-    TRIANGLE_DOWN = 'triangle_down'
-    TRIANGLE_UP = 'triangle_up'
-    VBAR = 'vbar'
-    X = 'x'
-
-    def __str__(self):
-        """String representation: The string method returns the
-        valid vispy symbol string for the Markers visual.
-        """
-        return self.value
+    ARROW = auto()
+    CLOBBER = auto()
+    CROSS = auto()
+    DIAMOND = auto()
+    DISC = auto()
+    HBAR = auto()
+    RING = auto()
+    SQUARE = auto()
+    STAR = auto()
+    TAILED_ARROW = auto()
+    TRIANGLE_DOWN = auto()
+    TRIANGLE_UP = auto()
+    VBAR = auto()
+    X = auto()
 
 
 # Mapping of symbol alias names to the deduplicated name
 SYMBOL_ALIAS = {
-    'o': Symbol.DISC,
-    '*': Symbol.STAR,
-    '+': Symbol.CROSS,
-    '-': Symbol.HBAR,
-    '->': Symbol.TAILED_ARROW,
     '>': Symbol.ARROW,
-    '^': Symbol.TRIANGLE_UP,
-    'v': Symbol.TRIANGLE_DOWN,
+    '+': Symbol.CROSS,
+    'o': Symbol.DISC,
+    '-': Symbol.HBAR,
     's': Symbol.SQUARE,
+    '*': Symbol.STAR,
+    '->': Symbol.TAILED_ARROW,
+    'v': Symbol.TRIANGLE_DOWN,
+    '^': Symbol.TRIANGLE_UP,
     '|': Symbol.VBAR,
 }
 
-
 SYMBOL_TRANSLATION = OrderedDict(
     [
         (Symbol.ARROW, trans._('arrow')),
@@ -99,6 +90,14 @@ SYMBOL_TRANSLATION = OrderedDict(
     ]
 )
 
+SYMBOL_TRANSLATION_INVERTED = {v: k for k, v in SYMBOL_TRANSLATION.items()}
+
+
+SYMBOL_DICT: dict[Union[str, Symbol], Symbol] = {x: x for x in Symbol}
+SYMBOL_DICT.update({str(x): x for x in Symbol})
+SYMBOL_DICT.update(SYMBOL_TRANSLATION_INVERTED)  # type: ignore[arg-type]
+SYMBOL_DICT.update(SYMBOL_ALIAS)  # type: ignore[arg-type]
+
 
 class Shading(StringEnum):
     """Shading: Shading mode for the points.
@@ -112,6 +111,18 @@ class Shading(StringEnum):
 
 
 SHADING_TRANSLATION = {
-    trans._("none"): Shading.NONE,
-    trans._("spherical"): Shading.SPHERICAL,
+    trans._('none'): Shading.NONE,
+    trans._('spherical'): Shading.SPHERICAL,
 }
+
+
+class PointsProjectionMode(StringEnum):
+    """
+    Projection mode for aggregating a thick nD slice onto displayed dimensions.
+
+        * NONE: ignore slice thickness, only using the dims point
+        * ALL: project all points in the slice onto displayed dimensions
+    """
+
+    NONE = auto()
+    ALL = auto()
