@@ -1,4 +1,4 @@
-from typing import Set, TypeVar
+from typing import TypeVar
 
 import numpy as np
 
@@ -146,17 +146,17 @@ def highlight(layer, event):
     layer._set_highlight()
 
 
-_T = TypeVar("_T")
+_T = TypeVar('_T')
 
 
-def _toggle_selected(selection: Set[_T], value: _T) -> Set[_T]:
+def _toggle_selected(selection: set[_T], value: _T) -> set[_T]:
     """Add or remove value from the selection set.
 
     This function returns a copy of the existing selection.
 
     Parameters
     ----------
-    selection: set
+    selection : set
         Set of selected data points to be modified.
     value : int
         Index of point to add or remove from selected data set.
