@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Optional
+from functools import cached_property
 
 import numpy as np
 import numpy.typing as npt
@@ -13,9 +13,22 @@ from napari.layers.shapes._shapes_utils import (
     triangulate_edge,
     triangulate_face,
 )
+from napari.settings import get_settings
 from napari.utils.misc import argsort
 from napari.utils.translations import trans
 
+try:
+    from PartSegCore_compiled_backend.triangulate import (
+        triangulate_path_edge_numpy,
+        triangulate_polygon_numpy_li,
+        triangulate_polygon_with_edge_numpy_li,
+    )
+
+except ImportError:
+    triangulate_path_edge_numpy = None
+    triangulate_polygon_numpy_li = None
+    triangulate_polygon_with_edge_numpy_li = None
+
 
 def _remove_path_duplicates_np(data: np.ndarray, closed: bool):
     # We add the first data point at the end to get the same length bool
@@ -129,7 +142,7 @@ class Shape(ABC):
     ) -> None:
         self._dims_order = dims_order or list(range(2))
         self._ndisplay = ndisplay
-        self.slice_key: Optional[npt.NDArray] = None
+        self.slice_key: npt.NDArray
 
         self._face_vertices = np.empty((0, self.ndisplay))
         self._face_triangles = np.empty((0, 3), dtype=np.uint32)
@@ -148,6 +161,16 @@ class Shape(ABC):
         self._data: npt.NDArray
         self._bounding_box = np.empty((0, self.ndisplay))
 
+    def __new__(cls, *args, **kwargs):
+        if (
+            get_settings().experimental.compiled_triangulation
+            and triangulate_path_edge_numpy is not None
+        ):
+            cls._set_meshes = cls._set_meshes_compiled
+        else:
+            cls._set_meshes = cls._set_meshes_py
+        return super().__new__(cls)
+
     @property
     @abstractmethod
     def data(self):
@@ -187,7 +210,7 @@ class Shape(ABC):
         self._dims_order = dims_order
         self._update_displayed_data()
 
-    @property
+    @cached_property
     def dims_displayed(self):
         """tuple: Dimensions that are displayed."""
         return self.dims_order[-self.ndisplay :]
@@ -206,7 +229,7 @@ class Shape(ABC):
         """tuple: Dimensions that are not displayed."""
         return self.dims_order[: -self.ndisplay]
 
-    @property
+    @cached_property
     def data_displayed(self):
         """(N, 2) array: Vertices of the shape that are currently displayed."""
         return self.data[:, self.dims_displayed]
@@ -231,7 +254,72 @@ class Shape(ABC):
     def z_index(self, z_index):
         self._z_index = z_index
 
-    def _set_meshes(
+    def _set_meshes_compiled(
+        self,
+        data: npt.NDArray,
+        closed: bool = True,
+        face: bool = True,
+        edge: bool = True,
+    ) -> None:
+        """Sets the face and edge meshes from a set of points.
+
+        Parameters
+        ----------
+        data : np.ndarray
+            Nx2 or Nx3 array specifying the shape to be triangulated
+        closed : bool
+            Bool which determines if the edge is closed or not
+        face : bool
+            Bool which determines if the face need to be traingulated
+        edge : bool
+            Bool which determines if the edge need to be traingulated
+        """
+        if data.shape[1] == 3:
+            self._set_meshes_py(data, closed=closed, face=face, edge=edge)
+            return
+
+        # if we are computing both edge and face triangles, we can do so
+        # with a single call to the compiled backend
+        if edge and face:
+            (triangles, vertices), (centers, offsets, edge_triangles) = (
+                triangulate_polygon_with_edge_numpy_li([data])
+            )
+            self._edge_vertices = centers
+            self._edge_offsets = offsets
+            self._edge_triangles = edge_triangles
+            self._face_vertices = vertices
+            self._face_triangles = triangles
+            return
+
+        # otherwise, we make individual calls to specialized functions
+        if edge:
+            centers, offsets, triangles = triangulate_path_edge_numpy(
+                data, closed=closed
+            )
+            self._edge_vertices = centers
+            self._edge_offsets = offsets
+            self._edge_triangles = triangles
+        else:
+            self._edge_vertices = np.empty((0, self.ndisplay))
+            self._edge_offsets = np.empty((0, self.ndisplay))
+            self._edge_triangles = np.empty((0, 3), dtype=np.uint32)
+        if face:
+            triangles, vertices = triangulate_polygon_numpy_li([data])
+            self._face_vertices = vertices
+            self._face_triangles = triangles
+        else:
+            self._face_vertices = np.empty((0, self.ndisplay))
+            self._face_triangles = np.empty((0, 3), dtype=np.uint32)
+
+    def _set_meshes(  # noqa: B027
+        self,
+        data: npt.NDArray,
+        closed: bool = True,
+        face: bool = True,
+        edge: bool = True,
+    ) -> None: ...
+
+    def _set_meshes_py(
         self,
         data: npt.NDArray,
         closed: bool = True,
@@ -322,7 +410,7 @@ class Shape(ABC):
             self._data[:, self.dims_displayed] @ transform.T
         )
         self._face_vertices = self._face_vertices @ transform.T
-
+        self.__dict__.pop('data_displayed', None)  # clear cache
         points = self.data_displayed
         points = remove_path_duplicates(points, closed=self._closed)
         centers, offsets, triangles = triangulate_edge(
@@ -337,6 +425,7 @@ class Shape(ABC):
                 np.max(self._data, axis=0),
             ]
         )
+        self._clean_cache()
 
     def shift(self, shift: npt.NDArray) -> None:
         """Performs a 2D shift on the shape
@@ -355,6 +444,7 @@ class Shape(ABC):
         self._bounding_box[:, self.dims_displayed] = (
             self._bounding_box[:, self.dims_displayed] + shift
         )
+        self._clean_cache()
 
     def scale(self, scale, center=None):
         """Performs a scaling on the shape
@@ -509,3 +599,9 @@ class Shape(ABC):
             mask = mask_p
 
         return mask
+
+    def _clean_cache(self) -> None:
+        if 'dims_displayed' in self.__dict__:
+            del self.__dict__['dims_displayed']
+        if 'data_displayed' in self.__dict__:
+            del self.__dict__['data_displayed']
