@@ -110,6 +110,18 @@ def test_shape_list_outline():
         assert np.array_equal(value_by_idx, value_by_idx_np)
 
 
+def test_shape_list_outline_two_shapes():
+    shape1 = Polygon([[0, 0], [0, 10], [10, 10], [10, 0]])
+    shape2 = Polygon([[20, 20], [20, 30], [30, 30], [30, 20]])
+    shape_list = ShapeList()
+    shape_list.add([shape1, shape2])
+
+    # check if the outline contains triangle with vertex of number 16
+
+    triangles = shape_list.outline([0, 1])[2]
+    assert np.any(triangles == 16)
+
+
 def test_nD_shapes():
     """Test adding shapes to ShapeList."""
     np.random.seed(0)
@@ -150,3 +162,14 @@ def test_bad_color_array(attribute):
     bad_color_array = np.array([[0, 0, 0, 1], [1, 1, 1, 1]])
     with pytest.raises(ValueError, match='must have shape'):
         setattr(shape_list, f'{attribute}_color', bad_color_array)
+
+
+def test_inside():
+    shape1 = Polygon(np.array([[0, 0, 0], [0, 1, 0], [0, 1, 1], [0, 0, 1]]))
+    shape2 = Polygon(np.array([[1, 0, 0], [1, 1, 0], [1, 1, 1], [1, 0, 1]]))
+    shape3 = Polygon(np.array([[2, 0, 0], [2, 1, 0], [2, 1, 1], [2, 0, 1]]))
+
+    shape_list = ShapeList()
+    shape_list.add([shape1, shape2, shape3])
+    shape_list.slice_key = (1,)
+    assert shape_list.inside((0.5, 0.5)) == 1
