@@ -4,6 +4,10 @@ import pytest
 
 from napari.layers import Tracks
 from napari.layers.tracks._track_utils import TrackManager
+from napari.utils._test_utils import (
+    validate_all_params_in_docstring,
+    validate_kwargs_sorted,
+)
 
 # def test_empty_tracks():
 #     """Test instantiating Tracks layer without data."""
@@ -19,7 +23,7 @@ dataframe_2dt = pd.DataFrame(
 
 
 @pytest.mark.parametrize(
-    "data", [data_array_2dt, data_list_2dt, dataframe_2dt]
+    'data', [data_array_2dt, data_list_2dt, dataframe_2dt]
 )
 def test_tracks_layer_2dt_ndim(data):
     """Test instantiating Tracks layer, check 2D+t dimensionality."""
@@ -35,7 +39,7 @@ dataframe_3dt = pd.DataFrame(
 
 
 @pytest.mark.parametrize(
-    "data", [data_array_3dt, data_list_3dt, dataframe_3dt]
+    'data', [data_array_3dt, data_list_3dt, dataframe_3dt]
 )
 def test_tracks_layer_3dt_ndim(data):
     """Test instantiating Tracks layer, check 3D+t dimensionality."""
@@ -55,18 +59,18 @@ def test_track_layer_data():
     data = np.zeros((100, 4))
     data[:, 1] = np.arange(100)
     layer = Tracks(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
 
 
 @pytest.mark.parametrize(
-    "timestamps", [np.arange(100, 200), np.arange(100, 300, 2)]
+    'timestamps', [np.arange(100, 200), np.arange(100, 300, 2)]
 )
 def test_track_layer_data_nonzero_starting_time(timestamps):
     """Test data with sparse timestamps or not starting at zero."""
     data = np.zeros((100, 4))
     data[:, 1] = timestamps
     layer = Tracks(data)
-    assert np.all(layer.data == data)
+    np.testing.assert_array_equal(layer.data, data)
 
 
 def test_track_layer_data_flipped():
@@ -76,14 +80,14 @@ def test_track_layer_data_flipped():
     data[:, 0] = np.arange(100)
     data = np.flip(data, axis=0)
     layer = Tracks(data)
-    assert np.all(layer.data == np.flip(data, axis=0))
+    np.testing.assert_array_equal(layer.data, np.flip(data, axis=0))
 
 
 properties_dict = {'time': np.arange(100)}
 properties_df = pd.DataFrame(properties_dict)
 
 
-@pytest.mark.parametrize("properties", [{}, properties_dict, properties_df])
+@pytest.mark.parametrize('properties', [{}, properties_dict, properties_df])
 def test_track_layer_properties(properties):
     """Test properties."""
     data = np.zeros((100, 4))
@@ -93,7 +97,7 @@ def test_track_layer_properties(properties):
         np.testing.assert_equal(layer.properties[k], v)
 
 
-@pytest.mark.parametrize("properties", [{}, properties_dict, properties_df])
+@pytest.mark.parametrize('properties', [{}, properties_dict, properties_df])
 def test_track_layer_properties_flipped(properties):
     """Test properties."""
     data = np.zeros((100, 4))
@@ -105,20 +109,20 @@ def test_track_layer_properties_flipped(properties):
         np.testing.assert_equal(layer.properties[k], np.flip(v))
 
 
-@pytest.mark.filterwarnings("ignore:.*track_id.*:UserWarning")
+@pytest.mark.filterwarnings('ignore:.*track_id.*:UserWarning')
 def test_track_layer_colorby_nonexistent():
     """Test error handling for non-existent properties with color_by"""
     data = np.zeros((100, 4))
     data[:, 1] = np.arange(100)
     non_existant_property = 'not_a_valid_key'
     assert non_existant_property not in properties_dict
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='not a valid property'):
         Tracks(
             data, properties=properties_dict, color_by=non_existant_property
         )
 
 
-@pytest.mark.filterwarnings("ignore:.*track_id.*:UserWarning")
+@pytest.mark.filterwarnings('ignore:.*track_id.*:UserWarning')
 def test_track_layer_properties_changed_colorby():
     """Test behaviour when changes to properties invalidate current color_by"""
     properties_dict_1 = {'time': np.arange(100), 'prop1': np.arange(100)}
@@ -153,7 +157,7 @@ def test_track_layer_reset_data():
     layer = Tracks(data, graph=graph, properties=properties)
     cropped_data = data[:10, :]
     layer.data = cropped_data
-    assert np.all(layer.data == cropped_data)
+    np.testing.assert_array_equal(layer.data, cropped_data)
     assert layer.graph == {}
 
 
@@ -161,7 +165,7 @@ def test_malformed_id():
     """Test for malformed track ID."""
     data = np.random.random((100, 4))
     data[:, 1] = np.arange(100)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='must be an integer'):
         Tracks(data)
 
 
@@ -171,7 +175,7 @@ def test_malformed_graph():
     data[:, 1] = np.arange(100)
     data[50:, 0] = 1
     graph = {1: [0], 2: [33]}
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match='node 2 not found'):
         Tracks(data, graph=graph)
 
 
@@ -218,7 +222,7 @@ def test_fast_points_lookup() -> None:
         assert points_lookup[t].stop == e
         assert points_lookup[t].stop - points_lookup[t].start == r
         unique_time = sorted_time[points_lookup[t]]
-        assert np.all(unique_time[0] == unique_time)
+        np.testing.assert_array_equal(unique_time[0], unique_time)
         total_length += len(unique_time)
 
     assert total_length == len(sorted_time)
@@ -231,7 +235,7 @@ def test_single_time_tracks() -> None:
     tracks = [[0, 5, 2, 3], [1, 5, 3, 4], [2, 5, 4, 5]]
     layer = Tracks(tracks)
 
-    assert np.all(layer.data == tracks)
+    np.testing.assert_array_equal(layer.data, tracks)
 
 
 def test_track_ids_ordering() -> None:
@@ -243,4 +247,55 @@ def test_track_ids_ordering() -> None:
     sorted_track_ids = [0, 0, 1, 1, 2]  # track_ids after sorting
 
     layer = Tracks(unsorted_data)
-    assert np.all(sorted_track_ids == layer.features["track_id"])
+    np.testing.assert_array_equal(sorted_track_ids, layer.features['track_id'])
+
+
+def test_changing_data_inplace() -> None:
+    """Test if layer can be refreshed after changing data in place."""
+
+    data = np.ones((100, 4))
+    data[:, 1] = np.arange(100)
+
+    layer = Tracks(data)
+
+    # Change data in place
+    # coordinates
+    layer.data[50:, -1] = 2
+    layer.refresh()
+
+    # time
+    layer.data[50:, 1] = np.arange(100, 150)
+    layer.refresh()
+
+    # track_id
+    layer.data[50:, 0] = 2
+    layer.refresh()
+
+
+def test_track_connex_validity() -> None:
+    """Test if track_connex is valid (i.e if the value False appears as many
+    times as there are tracks."""
+
+    data = np.zeros((11, 4))
+
+    # Track ids
+    data[:-1, 0] = np.repeat(np.arange(1, 6), 2)
+    # create edge case where a track has length one
+    data[-1, 0] = 6
+
+    # Time
+    data[:-1, 1] = np.array([0, 1] * 5)
+    data[-1, 1] = 0
+
+    layer = Tracks(data)
+
+    # number of tracks
+    n_tracks = 6
+
+    # the number of 'False' in the track_connex array should be equal to the number of tracks
+    assert np.sum(~layer._manager.track_connex) == n_tracks
+
+
+def test_docstring():
+    validate_all_params_in_docstring(Tracks)
+    validate_kwargs_sorted(Tracks)
