@@ -1,3 +1,5 @@
+from typing import Callable
+
 from napari.layers.base._base_constants import Mode
 from napari.layers.tracks.tracks import Tracks
 from napari.layers.utils.layer_utils import (
@@ -7,11 +9,15 @@ from napari.layers.utils.layer_utils import (
 from napari.utils.translations import trans
 
 
-def register_tracks_action(description: str, repeatable: bool = False):
+def register_tracks_action(
+    description: str, repeatable: bool = False
+) -> Callable[[Callable], Callable]:
     return register_layer_action(Tracks, description, repeatable)
 
 
-def register_tracks_mode_action(description):
+def register_tracks_mode_action(
+    description: str,
+) -> Callable[[Callable], Callable]:
     return register_layer_attr_action(Tracks, description, 'mode')
 
 
@@ -21,7 +27,7 @@ def activate_tracks_transform_mode(layer: Tracks) -> None:
 
 
 @register_tracks_mode_action(trans._('Pan/zoom'))
-def activate_tracks_pan_zoom_mode(layer: Tracks):
+def activate_tracks_pan_zoom_mode(layer: Tracks) -> None:
     layer.mode = str(Mode.PAN_ZOOM)
 
 
