@@ -260,7 +260,7 @@ class Tracks(Layer):
         )
         return state
 
-    def _set_view_slice(self):
+    def _set_view_slice(self) -> None:
         """Sets the view given the indices to slice with."""
 
         # if the displayed dims have changed, update the shader data
@@ -274,7 +274,7 @@ class Tracks(Layer):
 
         return
 
-    def _get_value(self, position) -> int:
+    def _get_value(self, position) -> Optional[int]:
         """Value of the data at a position in data coordinates.
 
         Use a kd-tree to lookup the ID of the nearest tree.
@@ -289,9 +289,12 @@ class Tracks(Layer):
         value : int or None
             Index of track that is at the current coordinate if any.
         """
-        return self._manager.get_value(np.array(position))
+        val = self._manager.get_value(np.array(position))
+        if val is None:
+            return None
+        return int(val)
 
-    def _update_thumbnail(self):
+    def _update_thumbnail(self) -> None:
         """Update thumbnail with current points and colors."""
         colormapped = np.zeros(self._thumbnail_shape)
         colormapped[..., 3] = 1
@@ -312,7 +315,7 @@ class Tracks(Layer):
                 points = self._view_data[thumbnail_indices]
             else:
                 points = self._view_data
-                thumbnail_indices = range(len(self._view_data))
+                thumbnail_indices = np.array(range(len(self._view_data)))
 
             # get the track coords here
             coords = np.floor(
@@ -323,6 +326,8 @@ class Tracks(Layer):
             )
 
             # modulate track colors as per colormap/current_time
+            assert self.track_times is not None
+            assert self.current_time is not None
             colors = self.track_colors[thumbnail_indices]
             times = self.track_times[thumbnail_indices]
             alpha = (self.head_length + self.current_time - times) / (
@@ -333,7 +338,8 @@ class Tracks(Layer):
             colormapped[coords[:, 1], coords[:, 0]] = colors
 
         colormapped[..., 3] *= self.opacity
-        self.thumbnail = colormapped
+        colormapped[np.isnan(colormapped)] = 0
+        self.thumbnail = colormapped.astype(np.uint8)
 
     @property
     def _view_data(self):
@@ -360,7 +366,7 @@ class Tracks(Layer):
         return data[:, (2, 1, 0)]  # z, y, x -> x, y, z
 
     @property
-    def current_time(self):
+    def current_time(self) -> Optional[int]:
         """current time according to the first dimension"""
         # TODO(arl): get the correct index here
         time_step = self._data_slice.point[0]
@@ -384,7 +390,7 @@ class Tracks(Layer):
         return self._manager.data
 
     @data.setter
-    def data(self, data: np.ndarray):
+    def data(self, data: np.ndarray) -> None:
         """set the data and build the vispy arrays for display"""
         # set the data and build the tracks
         self._manager.data = data
@@ -406,7 +412,7 @@ class Tracks(Layer):
         self._reset_editable()
 
     @property
-    def features(self):
+    def features(self) -> pd.DataFrame:
         """Dataframe-like features table.
 
         It is an implementation detail that this is a `pandas.DataFrame`. In the future,
@@ -438,7 +444,7 @@ class Tracks(Layer):
         return self._manager.properties
 
     @properties.setter
-    def properties(self, properties: dict[str, np.ndarray]):
+    def properties(self, properties: dict[str, np.ndarray]) -> None:
         """set track properties"""
         self.features = properties
 
@@ -453,7 +459,7 @@ class Tracks(Layer):
         return self._manager.graph
 
     @graph.setter
-    def graph(self, graph: dict[int, Union[int, list[int]]]):
+    def graph(self, graph: dict[int, Union[int, list[int]]]) -> None:
         """Set the track graph."""
         # Ignored type, because mypy can't handle different signatures
         # on getters and setters; see https://github.com/python/mypy/issues/3004
@@ -467,7 +473,7 @@ class Tracks(Layer):
         return self._tail_width
 
     @tail_width.setter
-    def tail_width(self, tail_width: float):
+    def tail_width(self, tail_width: float) -> None:
         self._tail_width: float = np.clip(tail_width, 0.5, self._max_width)
         self.events.tail_width()
 
@@ -477,7 +483,7 @@ class Tracks(Layer):
         return self._tail_length
 
     @tail_length.setter
-    def tail_length(self, tail_length: int):
+    def tail_length(self, tail_length: int) -> None:
         if tail_length > self._max_length:
             self._max_length = tail_length
         self._tail_length: int = tail_length
@@ -488,7 +494,7 @@ class Tracks(Layer):
         return self._head_length
 
     @head_length.setter
-    def head_length(self, head_length: int):
+    def head_length(self, head_length: int) -> None:
         if head_length > self._max_length:
             self._max_length = head_length
         self._head_length: int = head_length
@@ -500,10 +506,12 @@ class Tracks(Layer):
         return self._display_id
 
     @display_id.setter
-    def display_id(self, value: bool):
+    def display_id(self, value: bool) -> None:
         self._display_id = value
         self.events.display_id()
-        self.refresh()
+        # TODO: this refresh is only here to trigger setting the id text...
+        #       a bit overkill? But maybe for a future PR.
+        self.refresh(extent=False, thumbnail=False)
 
     @property
     def display_tail(self) -> bool:
@@ -511,7 +519,7 @@ class Tracks(Layer):
         return self._display_tail
 
     @display_tail.setter
-    def display_tail(self, value: bool):
+    def display_tail(self, value: bool) -> None:
         self._display_tail = value
         self.events.display_tail()
 
@@ -521,7 +529,7 @@ class Tracks(Layer):
         return self._display_graph
 
     @display_graph.setter
-    def display_graph(self, value: bool):
+    def display_graph(self, value: bool) -> None:
         self._display_graph = value
         self.events.display_graph()
 
@@ -530,7 +538,7 @@ class Tracks(Layer):
         return self._color_by
 
     @color_by.setter
-    def color_by(self, color_by: str):
+    def color_by(self, color_by: str) -> None:
         """set the property to color vertices by"""
         if color_by not in self.properties_to_color_by:
             raise ValueError(
@@ -549,7 +557,7 @@ class Tracks(Layer):
         return self._colormap
 
     @colormap.setter
-    def colormap(self, colormap: str):
+    def colormap(self, colormap: str) -> None:
         """set the default colormap"""
         if colormap not in AVAILABLE_COLORMAPS:
             raise ValueError(
@@ -570,11 +578,11 @@ class Tracks(Layer):
     # Ignored type because mypy doesn't recognise colormaps_dict as a property
     # TODO: investigate and fix this - not sure why this is the case?
     @colormaps_dict.setter  # type: ignore[attr-defined]
-    def colomaps_dict(self, colormaps_dict: dict[str, Colormap]):
+    def colomaps_dict(self, colormaps_dict: dict[str, Colormap]) -> None:
         # validate the dictionary entries?
         self._colormaps_dict = colormaps_dict
 
-    def _recolor_tracks(self):
+    def _recolor_tracks(self) -> None:
         """recolor the tracks"""
 
         # this catch prevents a problem coloring the tracks if the data is
@@ -612,7 +620,7 @@ class Tracks(Layer):
         return self._track_colors
 
     @property
-    def graph_connex(self) -> np.ndarray:
+    def graph_connex(self) -> Optional[np.ndarray]:
         """vertex connections for drawing the graph"""
         return self._manager.graph_connex
 
@@ -629,6 +637,7 @@ class Tracks(Layer):
     @property
     def track_labels(self) -> tuple:
         """return track labels at the current time"""
+        assert self.current_time is not None
         labels, positions = self._manager.track_labels(self.current_time)
 
         # if there are no labels, return empty for vispy
@@ -638,7 +647,7 @@ class Tracks(Layer):
         padded_positions = self._pad_display_data(positions)
         return labels, padded_positions
 
-    def _check_color_by_in_features(self):
+    def _check_color_by_in_features(self) -> None:
         if self._color_by not in self.features.columns:
             warn(
                 (
