@@ -4,7 +4,9 @@ import pytest
 from napari.layers import Image
 from napari.layers.utils.stack_utils import (
     images_to_stack,
+    merge_rgb,
     split_channels,
+    split_rgb,
     stack_to_images,
 )
 from napari.utils.transforms import Affine
@@ -138,6 +140,24 @@ def test_images_to_stack_none_scale():
     assert list(stack.translate) == [0, 0, -1, 2]
 
 
+def test_split_and_merge_rgb():
+    """Test merging 3 images with RGB colormaps into single RGB image."""
+    # Make an RGB
+    data = np.random.randint(0, 100, (10, 128, 128, 3))
+    stack = Image(data)
+    assert stack.rgb is True
+
+    # split the RGB into 3 images
+    images = split_rgb(stack)
+    assert len(images) == 3
+    colormaps = {image.colormap.name for image in images}
+    assert colormaps == {'red', 'green', 'blue'}
+
+    # merge the 3 images back into an RGB
+    rgb_image = merge_rgb(images)
+    assert rgb_image.rgb is True
+
+
 @pytest.fixture(
     params=[
         {
