@@ -1,4 +1,4 @@
-from typing import Any, Dict, Tuple, Union
+from typing import Any, Union
 
 import numpy as np
 
@@ -22,9 +22,9 @@ def guess_continuous(color_map: np.ndarray) -> bool:
         True of the property is guessed to be continuous, False if not.
     """
     # if the property is a floating type, guess continuous
-    return (
-        issubclass(color_map.dtype.type, np.floating)
-        or len(np.unique(color_map)) > 16
+    return issubclass(color_map.dtype.type, np.floating) or (
+        len(np.unique(color_map)) > 16
+        and issubclass(color_map.dtype.type, np.integer)
     )
 
 
@@ -48,8 +48,8 @@ def is_color_mapped(color, properties):
 def map_property(
     prop: np.ndarray,
     colormap: Colormap,
-    contrast_limits: Union[None, Tuple[float, float]] = None,
-) -> Tuple[np.ndarray, Tuple[float, float]]:
+    contrast_limits: Union[None, tuple[float, float]] = None,
+) -> tuple[np.ndarray, tuple[float, float]]:
     """Apply a colormap to a property
 
     Parameters
@@ -74,8 +74,8 @@ def map_property(
 
 
 def _validate_colormap_mode(
-    values: Dict[str, Any]
-) -> Tuple[np.ndarray, Dict[str, Any]]:
+    values: dict[str, Any],
+) -> tuple[np.ndarray, dict[str, Any]]:
     """Validate the ColorManager field values specific for colormap mode
     This is called by the root_validator in ColorManager
 
@@ -118,8 +118,8 @@ def _validate_colormap_mode(
 
 
 def _validate_cycle_mode(
-    values: Dict[str, Any]
-) -> Tuple[np.ndarray, Dict[str, Any]]:
+    values: dict[str, Any],
+) -> tuple[np.ndarray, dict[str, Any]]:
     """Validate the ColorManager field values specific for color cycle mode
     This is called by the root_validator in ColorManager
 
