@@ -3,15 +3,15 @@ normalize and broadcast the color inputs they receive into a more standardized f
 a numpy array with N rows, N being the number of data points, and a dtype of np.float32.
 
 """
+
 import warnings
 from itertools import cycle
-from typing import Union
 
 import numpy as np
 
-from ...utils.colormaps.colormap_utils import ColorType
-from ...utils.colormaps.standardize_color import transform_color
-from ...utils.translations import trans
+from napari.utils.colormaps.colormap_utils import ColorType
+from napari.utils.colormaps.standardize_color import transform_color
+from napari.utils.translations import trans
 
 
 def transform_color_with_defaults(
@@ -41,7 +41,7 @@ def transform_color_with_defaults(
     except (AttributeError, ValueError, KeyError):
         warnings.warn(
             trans._(
-                "The provided {elem_name} parameter contained illegal values, resetting all {elem_name} values to {default}.",
+                'The provided {elem_name} parameter contained illegal values, resetting all {elem_name} values to {default}.',
                 deferred=True,
                 elem_name=elem_name,
                 default=default,
@@ -52,7 +52,7 @@ def transform_color_with_defaults(
         if (len(transformed) != 1) and (len(transformed) != num_entries):
             warnings.warn(
                 trans._(
-                    "The provided {elem_name} parameter has {length} entries, while the data contains {num_entries} entries. Setting {elem_name} to {default}.",
+                    'The provided {elem_name} parameter has {length} entries, while the data contains {num_entries} entries. Setting {elem_name} to {default}.',
                     deferred=True,
                     elem_name=elem_name,
                     length=len(colors),
@@ -65,13 +65,13 @@ def transform_color_with_defaults(
 
 
 def transform_color_cycle(
-    color_cycle: Union[ColorType, cycle], elem_name: str, default: str
-) -> cycle:
+    color_cycle: ColorType, elem_name: str, default: str
+) -> tuple['cycle[np.ndarray]', np.ndarray]:
     """Helper method to return an Nx4 np.array from an arbitrary user input.
 
     Parameters
     ----------
-    color_cycle : ColorType, cycle
+    color_cycle : ColorType
         The desired colors for each of the data points
     elem_name : str
         Whether we're trying to set the face color or edge color of the layer
@@ -81,7 +81,7 @@ def transform_color_cycle(
     Returns
     -------
     transformed_color_cycle : cycle
-        cycle of Nx4 numpy arrays with a dtype of np.float32
+        cycle of shape (4,) numpy arrays with a dtype of np.float32
     transformed_colors : np.ndarray
         input array of colors transformed to RGBA
     """
@@ -97,7 +97,7 @@ def transform_color_cycle(
 
 
 def normalize_and_broadcast_colors(
-    num_entries: int, colors: ColorType
+    num_entries: int, colors: np.ndarray
 ) -> np.ndarray:
     """Takes an input color array and forces into being the length of ``data``.
 
@@ -112,7 +112,7 @@ def normalize_and_broadcast_colors(
     ----------
     num_entries : int
         The number of data elements in the layer
-    colors : ColorType
+    colors : np.ndarray
         The user's input after being normalized by transform_color_with_defaults
 
     Returns
@@ -129,7 +129,7 @@ def normalize_and_broadcast_colors(
     if len(colors) != 1:
         warnings.warn(
             trans._(
-                "The number of supplied colors mismatch the number of given data points. Length of data is {num_entries}, while the number of colors is {length}. Color for all points is reset to white.",
+                'The number of supplied colors mismatch the number of given data points. Length of data is {num_entries}, while the number of colors is {length}. Color for all points is reset to white.',
                 deferred=True,
                 num_entries=num_entries,
                 length=len(colors),
