@@ -1,6 +1,7 @@
 import warnings
+from collections.abc import Sequence
 from copy import deepcopy
-from typing import Any, Dict, List, Sequence, Tuple, Union
+from typing import Any, Optional, Union
 
 import numpy as np
 import pandas as pd
@@ -75,7 +76,7 @@ class TextManager(EventedModel):
         The location of the text origin relative to the bounding box.
         Should be 'center', 'upper_left', 'upper_right', 'lower_left', or 'lower_right'.
     translation : np.ndarray
-        Offset from the anchor point.
+        Offset from the anchor point in data coordinates.
     rotation : float
         Angle of the text elements around the anchor point. Default value is 0.
     """
@@ -137,7 +138,7 @@ class TextManager(EventedModel):
         # Trigger the main event for vispy layers.
         self.events(Event(type_name='refresh'))
 
-    def refresh_text(self, properties: Dict[str, np.ndarray]):
+    def refresh_text(self, properties: dict[str, np.ndarray]):
         """Refresh all of the current text elements using updated properties values
 
         Parameters
@@ -211,7 +212,7 @@ class TextManager(EventedModel):
         self.events.values()
         self.color._apply(features)
 
-    def _copy(self, indices: List[int]) -> dict:
+    def _copy(self, indices: list[int]) -> dict:
         """Copies all encoded values at the given indices."""
         return {
             'string': _get_style_values(self.string, indices),
@@ -225,8 +226,11 @@ class TextManager(EventedModel):
         self.color._append(color)
 
     def compute_text_coords(
-        self, view_data: np.ndarray, ndisplay: int
-    ) -> Tuple[np.ndarray, str, str]:
+        self,
+        view_data: np.ndarray,
+        ndisplay: int,
+        order: Optional[tuple[int, ...]] = None,
+    ) -> tuple[np.ndarray, str, str]:
         """Calculate the coordinates for each text element in view
 
         Parameters
@@ -235,6 +239,9 @@ class TextManager(EventedModel):
             The in view data from the layer
         ndisplay : int
             The number of dimensions being displayed in the viewer
+        order : tuple of ints, optional
+            The display order of the dimensions in the layer.
+            If None, implies ``range(ndisplay)``.
 
         Returns
         -------
@@ -248,7 +255,20 @@ class TextManager(EventedModel):
         anchor_coords, anchor_x, anchor_y = get_text_anchors(
             view_data, ndisplay, self.anchor
         )
-        text_coords = anchor_coords + self.translation
+        # The translation should either be a scalar or be as long as
+        # the dimensionality of the associated layer.
+        # We do not have direct knowledge of that dimensionality, but
+        # can infer enough information to get the translation coordinates
+        # that need to offset the anchor coordinates.
+        ndim_coords = min(ndisplay, anchor_coords.shape[1])
+        translation = self.translation
+        if translation.size > 1:
+            if order is None:
+                translation = self.translation[-ndim_coords:]
+            else:
+                order_displayed = list(order[-ndim_coords:])
+                translation = self.translation[order_displayed]
+        text_coords = anchor_coords + translation
         return text_coords, anchor_x, anchor_y
 
     def view_text(self, indices_view: np.ndarray) -> np.ndarray:
@@ -345,7 +365,7 @@ class TextManager(EventedModel):
         # values if needed.
         self.apply(features)
 
-    @validator('blending', pre=True, always=True)
+    @validator('blending', pre=True, always=True, allow_reuse=True)
     def _check_blending_mode(cls, blending):
         blending_mode = Blending(blending)
 
