@@ -98,6 +98,5 @@ def test_plugin_extension_assignment(napari_plugin_manager):
         # reader may not recognize extension
         tnpm.assign_reader_to_extensions('test_plugin', '.pndfdg')
 
-    with pytest.raises(ValueError):
-        # invalid plugin name
+    with pytest.raises(ValueError, match='is not a valid reader'):
         tnpm.assign_reader_to_extensions('test_pldfdfugin', '.png')
