@@ -391,9 +391,9 @@ def napari_write_vectors(path: str, data: Any, meta: dict) -> Optional[str]:
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_function() -> (
-    Union[FunctionType, list[FunctionType]]
-):
+def napari_experimental_provide_function() -> Union[
+    FunctionType, list[FunctionType]
+]:
     """Provide function(s) that can be passed to magicgui.
 
     This hook specification is marked as experimental as the API or how the
@@ -427,9 +427,9 @@ def napari_experimental_provide_function() -> (
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_dock_widget() -> (
-    Union[AugmentedWidget, list[AugmentedWidget]]
-):
+def napari_experimental_provide_dock_widget() -> Union[
+    AugmentedWidget, list[AugmentedWidget]
+]:
     """Provide functions that return widgets to be docked in the viewer.
 
     This hook specification is marked as experimental as the API or how the
@@ -501,9 +501,9 @@ def napari_experimental_provide_dock_widget() -> (
 
 
 @napari_hook_specification(historic=True)
-def napari_experimental_provide_theme() -> (
-    dict[str, dict[str, Union[str, tuple, list]]]
-):
+def napari_experimental_provide_theme() -> dict[
+    str, dict[str, Union[str, tuple, list]]
+]:
     """Provide GUI with a set of colors used through napari. This hook allows you to
     provide additional color schemes so you can accomplish your desired styling.
 
