@@ -1,15 +1,17 @@
 import re
+from collections.abc import Iterable, Iterator
 from functools import lru_cache
 from itertools import product
 from pathlib import Path
-from typing import Dict, Iterable, Iterator, Optional, Tuple, Union
+from typing import Optional, Union
 
 from napari.utils._appdirs import user_cache_dir
 from napari.utils.translations import trans
 
+LOADING_GIF_PATH = str((Path(__file__).parent / 'loading.gif').resolve())
 ICON_PATH = (Path(__file__).parent / 'icons').resolve()
 ICONS = {x.stem: str(x) for x in ICON_PATH.iterdir() if x.suffix == '.svg'}
-PLUGIN_FILE_NAME = "plugin.txt"
+PLUGIN_FILE_NAME = 'plugin.txt'
 
 
 def get_icon_path(name: str) -> str:
@@ -17,7 +19,7 @@ def get_icon_path(name: str) -> str:
     if name not in ICONS:
         raise ValueError(
             trans._(
-                "unrecognized icon name: {name!r}. Known names: {icons}",
+                'unrecognized icon name: {name!r}. Known names: {icons}',
                 deferred=True,
                 name=name,
                 icons=set(ICONS),
@@ -43,7 +45,7 @@ def get_raw_svg(path: str) -> str:
 
 @lru_cache
 def get_colorized_svg(
-    path_or_xml: Union[str, Path], color: str = None, opacity=1
+    path_or_xml: Union[str, Path], color: Optional[str] = None, opacity=1.0
 ) -> str:
     """Return a colorized version of the SVG XML at ``path``.
 
@@ -60,7 +62,7 @@ def get_colorized_svg(
     if not svg_elem.search(xml):
         raise ValueError(
             trans._(
-                "Could not detect svg tag in {path_or_xml!r}",
+                'Could not detect svg tag in {path_or_xml!r}',
                 deferred=True,
                 path_or_xml=path_or_xml,
             )
@@ -72,10 +74,10 @@ def get_colorized_svg(
 
 def generate_colorized_svgs(
     svg_paths: Iterable[Union[str, Path]],
-    colors: Iterable[Union[str, Tuple[str, str]]],
+    colors: Iterable[Union[str, tuple[str, str]]],
     opacities: Iterable[float] = (1.0,),
-    theme_override: Optional[Dict[str, str]] = None,
-) -> Iterator[Tuple[str, str]]:
+    theme_override: Optional[dict[str, str]] = None,
+) -> Iterator[tuple[str, str]]:
     """Helper function to generate colorized SVGs.
 
     This is a generator that yields tuples of ``(alias, icon_xml)`` for every
@@ -126,10 +128,10 @@ def generate_colorized_svgs(
 
             clrkey, theme_key = color
             theme_key = theme_override.get(svg_stem, theme_key)
-            color = getattr(get_theme(clrkey, False), theme_key).as_hex()
+            color = getattr(get_theme(clrkey), theme_key).as_hex()
             # convert color to string to fit get_colorized_svg signature
 
-        op_key = "" if op == 1 else f"_{op * 100:.0f}"
+        op_key = '' if op == 1 else f'_{op * 100:.0f}'
         alias = ALIAS_T.format(color=clrkey, svg_stem=svg_stem, opacity=op_key)
         yield alias, get_colorized_svg(path, color, op)
 
@@ -137,9 +139,9 @@ def generate_colorized_svgs(
 def write_colorized_svgs(
     dest: Union[str, Path],
     svg_paths: Iterable[Union[str, Path]],
-    colors: Iterable[Union[str, Tuple[str, str]]],
+    colors: Iterable[Union[str, tuple[str, str]]],
     opacities: Iterable[float] = (1.0,),
-    theme_override: Optional[Dict[str, str]] = None,
+    theme_override: Optional[dict[str, str]] = None,
 ):
     dest = Path(dest)
     dest.mkdir(parents=True, exist_ok=True)
