@@ -1,38 +1,47 @@
 from __future__ import annotations
 
+import contextlib
 import logging
 import os
-from collections.abc import Mapping
+from collections.abc import Mapping, Sequence
 from functools import partial
 from pathlib import Path
-from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Tuple, cast
+from typing import TYPE_CHECKING, Optional, cast
 from warnings import warn
 
-from pydantic import BaseModel, BaseSettings, ValidationError
-from pydantic.env_settings import SettingsError
-from pydantic.error_wrappers import display_errors
-
-from ..utils.events import EmitterGroup, EventedModel
-from ..utils.misc import deep_update
-from ..utils.translations import trans
-from ._yaml import PydanticYamlMixin
+from napari._pydantic_compat import (
+    BaseModel,
+    BaseSettings,
+    SettingsError,
+    ValidationError,
+    display_errors,
+)
+from napari.settings._yaml import PydanticYamlMixin
+from napari.utils.events import EmitterGroup, EventedModel
+from napari.utils.misc import deep_update
+from napari.utils.translations import trans
 
 _logger = logging.getLogger(__name__)
 
 if TYPE_CHECKING:
-    from typing import AbstractSet, Any, Union
+    from collections.abc import Set as AbstractSet
+    from typing import Any, Union
 
-    from pydantic.env_settings import EnvSettingsSource, SettingsSourceCallable
-
-    from ..utils.events import Event
+    from napari._pydantic_compat import (
+        EnvSettingsSource,
+        SettingsSourceCallable,
+    )
+    from napari.utils.events import Event
 
     IntStr = Union[int, str]
     AbstractSetIntStr = AbstractSet[IntStr]
-    DictStrAny = Dict[str, Any]
+    DictStrAny = dict[str, Any]
     MappingIntStrAny = Mapping[IntStr, Any]
 
+Dict = dict  # rename, because EventedSettings has method dict
 
-class EventedSettings(BaseSettings, EventedModel):  # type: ignore[misc]
+
+class EventedSettings(BaseSettings, EventedModel):
     """A variant of EventedModel designed for settings.
 
     Pydantic's BaseSettings model will attempt to determine the values of any
@@ -40,6 +49,10 @@ class EventedSettings(BaseSettings, EventedModel):  # type: ignore[misc]
     """
 
     # provide config_path=None to prevent reading from disk.
+
+    class Config(EventedModel.Config):
+        pass
+
     def __init__(self, **values: Any) -> None:
         super().__init__(**values)
         self.events.add(changed=None)
@@ -57,7 +70,7 @@ class EventedSettings(BaseSettings, EventedModel):  # type: ignore[misc]
                 def _warn_restart(*_):
                     warn(
                         trans._(
-                            "Restart required for this change to take effect.",
+                            'Restart required for this change to take effect.',
                             deferred=True,
                         )
                     )
@@ -65,7 +78,7 @@ class EventedSettings(BaseSettings, EventedModel):  # type: ignore[misc]
     def _on_sub_event(self, event: Event, field=None):
         """emit the field.attr name and new value"""
         if field:
-            field += "."
+            field += '.'
         value = getattr(event, 'value', None)
         self.events.changed(key=f'{field}{event._type}', value=value)
 
@@ -115,7 +128,7 @@ class EventedConfigFileSettings(EventedSettings, PydanticYamlMixin):
         """Return the path to/from which settings be saved/loaded."""
         return self._config_path
 
-    def dict(  # type: ignore [override]
+    def dict(
         self,
         *,
         include: Union[AbstractSetIntStr, MappingIntStrAny] = None,  # type: ignore
@@ -166,7 +179,7 @@ class EventedConfigFileSettings(EventedSettings, PydanticYamlMixin):
         if not path:
             raise ValueError(
                 trans._(
-                    "No path provided in config or save argument.",
+                    'No path provided in config or save argument.',
                     deferred=True,
                 )
             )
@@ -179,13 +192,13 @@ class EventedConfigFileSettings(EventedSettings, PydanticYamlMixin):
         """Encode and dump `data` to `path` using a path-appropriate encoder."""
         if str(path).endswith(('.yaml', '.yml')):
             _data = self._yaml_dump(data)
-        elif str(path).endswith(".json"):
+        elif str(path).endswith('.json'):
             json_dumps = self.__config__.json_dumps
             _data = json_dumps(data, default=self.__json_encoder__)
         else:
             raise NotImplementedError(
                 trans._(
-                    "Can only currently dump to `.json` or `.yaml`, not {path!r}",
+                    'Can only currently dump to `.json` or `.yaml`, not {path!r}',
                     deferred=True,
                     path=path,
                 )
@@ -226,7 +239,7 @@ class EventedConfigFileSettings(EventedSettings, PydanticYamlMixin):
             init_settings: SettingsSourceCallable,
             env_settings: EnvSettingsSource,
             file_secret_settings: SettingsSourceCallable,
-        ) -> Tuple[SettingsSourceCallable, ...]:
+        ) -> tuple[SettingsSourceCallable, ...]:
             """customise the way data is loaded.
 
             This does 2 things:
@@ -240,17 +253,19 @@ class EventedConfigFileSettings(EventedSettings, PydanticYamlMixin):
             the return list to change the priority of sources.
             """
             cls._env_settings = nested_env_settings(env_settings)
-            return (  # type: ignore [return-value]
+            return (  # type: ignore[return-value]
                 init_settings,
                 cls._env_settings,
                 cls._config_file_settings_source,
                 file_secret_settings,
             )
+            # Even when EventedConfigFileSettings is a subclass of BaseSettings,
+            # mypy do not see this
 
         @classmethod
         def _config_file_settings_source(
             cls, settings: EventedConfigFileSettings
-        ) -> Dict[str, Any]:
+        ) -> dict[str, Any]:
             return config_file_settings_source(settings)
 
 
@@ -276,7 +291,7 @@ def nested_env_settings(
     nesting as well.
     """
 
-    def _inner(settings: BaseSettings) -> Dict[str, Any]:
+    def _inner(settings: BaseSettings) -> dict[str, Any]:
         # first call the original implementation
         d = super_eset(settings)
 
@@ -305,31 +320,33 @@ def nested_env_settings(
                     # otherwise, look for the standard nested env var
                     else:
                         env_val = env_vars.get(f'{env_name}_{subf.name}')
-                        if env_val is not None:
-                            break
 
-                is_complex, all_json_fail = super_eset.field_is_complex(subf)
-                if env_val is not None and is_complex:
-                    try:
-                        env_val = settings.__config__.json_loads(env_val)
-                    except ValueError as e:
-                        if not all_json_fail:
-                            msg = trans._(
-                                'error parsing JSON for "{env_name}"',
-                                deferred=True,
-                                env_name=env_name,
+                    is_complex, all_json_fail = super_eset.field_is_complex(
+                        subf
+                    )
+                    if env_val is not None and is_complex:
+                        try:
+                            env_val = settings.__config__.json_loads(env_val)
+                        except ValueError as e:
+                            if not all_json_fail:
+                                msg = trans._(
+                                    'error parsing JSON for "{env_name}"',
+                                    deferred=True,
+                                    env_name=env_name,
+                                )
+                                raise SettingsError(msg) from e
+
+                        if isinstance(env_val, dict):
+                            explode = super_eset.explode_env_vars(
+                                field, env_vars
                             )
-                            raise SettingsError(msg) from e
+                            env_val = deep_update(env_val, explode)
 
-                    if isinstance(env_val, dict):
-                        explode = super_eset.explode_env_vars(field, env_vars)
-                        env_val = deep_update(env_val, explode)
-
-                # if we found an env var, store it and return it
-                if env_val is not None:
-                    if field.alias not in d:
-                        d[field.alias] = {}
-                    d[field.alias][subf.name] = env_val
+                    # if we found an env var, store it and return it
+                    if env_val is not None:
+                        if field.alias not in d:
+                            d[field.alias] = {}
+                        d[field.alias][subf.name] = env_val
         return d
 
     return _inner
@@ -337,7 +354,7 @@ def nested_env_settings(
 
 def config_file_settings_source(
     settings: EventedConfigFileSettings,
-) -> Dict[str, Any]:
+) -> dict[str, Any]:
     """Read config files during init of an EventedConfigFileSettings obj.
 
     The two important values are the `settings._config_path`
@@ -363,7 +380,7 @@ def config_file_settings_source(
     default_cfg = getattr(default_cfg, 'default', None)
 
     # if the config has a `sources` list, read those too and merge.
-    sources = list(getattr(settings.__config__, 'sources', []))
+    sources: list[str] = list(getattr(settings.__config__, 'sources', []))
     if config_path:
         sources.append(config_path)
     if not sources:
@@ -373,17 +390,17 @@ def config_file_settings_source(
     for path in sources:
         if not path:
             continue  # pragma: no cover
-        _path = Path(path).expanduser().resolve()
+        path_ = Path(path).expanduser().resolve()
 
         # if the requested config path does not exist, move on to the next
-        if not _path.is_file():
+        if not path_.is_file():
             # if it wasn't the `_config_path` stated in the BaseModel itself,
             # we warn, since this would have been user provided.
-            if _path != default_cfg:
+            if path_ != default_cfg:
                 _logger.warning(
                     trans._(
-                        "Requested config path is not a file: {path}",
-                        path=_path,
+                        'Requested config path is not a file: {path}',
+                        path=path_,
                     )
                 )
             continue
@@ -391,12 +408,12 @@ def config_file_settings_source(
         # get loader for yaml/json
         if str(path).endswith(('.yaml', '.yml')):
             load = __import__('yaml').safe_load
-        elif str(path).endswith(".json"):
+        elif str(path).endswith('.json'):
             load = __import__('json').load
         else:
             warn(
                 trans._(
-                    "Unrecognized file extension for config_path: {path}",
+                    'Unrecognized file extension for config_path: {path}',
                     path=path,
                 )
             )
@@ -404,17 +421,17 @@ def config_file_settings_source(
 
         try:
             # try to parse the config file into a dict
-            new_data = load(_path.read_text()) or {}
-        except Exception as err:
+            new_data = load(path_.read_text()) or {}
+        except Exception as err:  # noqa: BLE001
             _logger.warning(
                 trans._(
-                    "The content of the napari settings file could not be read\n\nThe default settings will be used and the content of the file will be replaced the next time settings are changed.\n\nError:\n{err}",
+                    'The content of the napari settings file could not be read\n\nThe default settings will be used and the content of the file will be replaced the next time settings are changed.\n\nError:\n{err}',
                     deferred=True,
                     err=err,
                 )
             )
             continue
-        assert isinstance(new_data, dict), _path.read_text()
+        assert isinstance(new_data, dict), path_.read_text()
         deep_update(data, new_data, copy=False)
 
     try:
@@ -428,16 +445,14 @@ def config_file_settings_source(
         # if errors occur, we still want to boot, so we just remove bad keys
         errors = err.errors()
         msg = trans._(
-            "Validation errors in config file(s).\nThe following fields have been reset to the default value:\n\n{errors}\n",
+            'Validation errors in config file(s).\nThe following fields have been reset to the default value:\n\n{errors}\n',
             deferred=True,
             errors=display_errors(errors),
         )
-        try:
+        with contextlib.suppress(Exception):
             # we're about to nuke some settings, so just in case... try backup
-            backup_path = _path.parent / f'{_path.stem}.BAK{_path.suffix}'
-            backup_path.write_text(_path.read_text())
-        except Exception:
-            pass
+            backup_path = path_.parent / f'{path_.stem}.BAK{path_.suffix}'
+            backup_path.write_text(path_.read_text())
 
         _logger.warning(msg)
         try:
@@ -454,7 +469,7 @@ def config_file_settings_source(
     return data
 
 
-def _remove_bad_keys(data: dict, keys: List[Tuple[Union[int, str], ...]]):
+def _remove_bad_keys(data: dict, keys: list[tuple[Union[int, str], ...]]):
     """Remove list of keys (as string tuples) from dict (in place).
 
     Parameters
