@@ -19,7 +19,7 @@ from napari.utils.translations import trans
 
 _CFG_PATH = os.getenv('NAPARI_CONFIG', _DEFAULT_CONFIG_PATH)
 
-CURRENT_SCHEMA_VERSION = Version(0, 5, 0)
+CURRENT_SCHEMA_VERSION = Version(0, 6, 0)
 
 
 class NapariSettings(EventedConfigFileSettings):
@@ -33,36 +33,36 @@ class NapariSettings(EventedConfigFileSettings):
     # 3. You don't need to touch this value if you're just adding a new option
     schema_version: Version = Field(
         CURRENT_SCHEMA_VERSION,
-        description=trans._("Napari settings schema version."),
+        description=trans._('Napari settings schema version.'),
     )
 
     application: ApplicationSettings = Field(
         default_factory=ApplicationSettings,
-        title=trans._("Application"),
-        description=trans._("Main application settings."),
+        title=trans._('Application'),
+        description=trans._('Main application settings.'),
     )
     appearance: AppearanceSettings = Field(
         default_factory=AppearanceSettings,
-        title=trans._("Appearance"),
-        description=trans._("User interface appearance settings."),
+        title=trans._('Appearance'),
+        description=trans._('User interface appearance settings.'),
         allow_mutation=False,
     )
     plugins: PluginsSettings = Field(
         default_factory=PluginsSettings,
-        title=trans._("Plugins"),
-        description=trans._("Plugins settings."),
+        title=trans._('Plugins'),
+        description=trans._('Plugins settings.'),
         allow_mutation=False,
     )
     shortcuts: ShortcutsSettings = Field(
         default_factory=ShortcutsSettings,
-        title=trans._("Shortcuts"),
-        description=trans._("Shortcut settings."),
+        title=trans._('Shortcuts'),
+        description=trans._('Shortcut settings.'),
         allow_mutation=False,
     )
     experimental: ExperimentalSettings = Field(
         default_factory=ExperimentalSettings,
-        title=trans._("Experimental"),
-        description=trans._("Experimental settings."),
+        title=trans._('Experimental'),
+        description=trans._('Experimental settings.'),
         allow_mutation=False,
     )
 
