@@ -195,7 +195,7 @@ def test_model_fields_are_annotated(test_settings):
         if difference:
             errors.append(
                 f"Model '{model.__name__}' does not provide annotations "
-                f"for the fields:\n{', '.join(repr(f) for f in difference)}"
+                f'for the fields:\n{", ".join(repr(f) for f in difference)}'
             )
 
     if errors:
