@@ -1,8 +1,9 @@
-"""Dask cache utilities.
-"""
+"""Dask cache utilities."""
+
 import collections.abc
 import contextlib
-from typing import Callable, ContextManager, Optional, Tuple
+from collections.abc import Iterator
+from typing import Any, Callable, Optional
 
 import dask
 import dask.array as da
@@ -15,6 +16,10 @@ from dask.cache import Cache
 _DASK_CACHE = Cache(1)
 _DEFAULT_MEM_FRACTION = 0.25
 
+DaskIndexer = Callable[
+    [], contextlib.AbstractContextManager[Optional[tuple[dict, Cache]]]
+]
+
 
 def resize_dask_cache(
     nbytes: Optional[int] = None, mem_fraction: Optional[float] = None
@@ -57,14 +62,14 @@ def resize_dask_cache(
     from psutil import virtual_memory
 
     if nbytes is None and mem_fraction is not None:
-        nbytes = virtual_memory().total * mem_fraction
+        nbytes = int(virtual_memory().total * mem_fraction)
 
     avail = _DASK_CACHE.cache.available_bytes
     # if we don't have a cache already, create one.
     if avail == 1:
         # If neither nbytes nor mem_fraction was provided, use default
         if nbytes is None:
-            nbytes = virtual_memory().total * _DEFAULT_MEM_FRACTION
+            nbytes = int(virtual_memory().total * _DEFAULT_MEM_FRACTION)
         _DASK_CACHE.cache.resize(nbytes)
     elif nbytes is not None and nbytes != _DASK_CACHE.cache.available_bytes:
         # if the cache has already been registered, then calling
@@ -74,7 +79,7 @@ def resize_dask_cache(
     return _DASK_CACHE
 
 
-def _is_dask_data(data) -> bool:
+def _is_dask_data(data: Any) -> bool:
     """Return True if data is a dask array or a list/tuple of dask arrays."""
     return isinstance(data, da.Array) or (
         isinstance(data, collections.abc.Sequence)
@@ -82,9 +87,7 @@ def _is_dask_data(data) -> bool:
     )
 
 
-def configure_dask(
-    data, cache=True
-) -> Callable[[], ContextManager[Optional[Tuple[dict, Cache]]]]:
+def configure_dask(data: Any, cache: bool = True) -> DaskIndexer:
     """Spin up cache and return context manager that optimizes Dask indexing.
 
     This function determines whether data is a dask array or list of dask
@@ -137,8 +140,10 @@ def configure_dask(
     _cache = resize_dask_cache() if cache else contextlib.nullcontext()
 
     @contextlib.contextmanager
-    def dask_optimized_slicing(memfrac=0.5):
-        opts = {"optimization.fuse.active": False}
+    def dask_optimized_slicing(
+        memfrac: float = 0.5,
+    ) -> Iterator[tuple[Any, Any]]:
+        opts = {'optimization.fuse.active': False}
         with dask.config.set(opts) as cfg, _cache as c:
             yield cfg, c
 
