@@ -146,7 +146,7 @@ def test_minimum_dtype_for_labels(num, dtype):
     assert _accelerated_cmap.minimum_dtype_for_labels(num) == dtype
 
 
-@pytest.fixture()
+@pytest.fixture
 def _disable_jit(monkeypatch):
     """Fixture to temporarily disable numba JIT during testing.
 
@@ -176,7 +176,7 @@ def test_cast_labels_to_minimum_type_auto(num: int, dtype, monkeypatch):
     assert cast_arr[2] == 10**6 % num + 5
 
 
-@pytest.fixture()
+@pytest.fixture
 def direct_label_colormap():
     return DirectLabelColormap(
         color_dict={
