@@ -2,32 +2,32 @@
 
 see module docstring of evented_list.py for more details
 """
+
 from __future__ import annotations
 
+import contextlib
 import logging
 from collections import defaultdict
+from collections.abc import Generator, Iterable, MutableSequence
 from typing import (
-    DefaultDict,
-    Generator,
-    Iterable,
     NewType,
-    Tuple,
+    Optional,
     TypeVar,
     Union,
     cast,
     overload,
 )
 
-from ...translations import trans
-from ..event import Event
-from ._evented_list import EventedList, Index
+from napari.utils.events.containers._evented_list import EventedList, Index
+from napari.utils.events.event import Event
+from napari.utils.translations import trans
 
 logger = logging.getLogger(__name__)
 
-NestedIndex = Tuple[Index, ...]
+NestedIndex = tuple[Index, ...]
 MaybeNestedIndex = Union[Index, NestedIndex]
-ParentIndex = NewType('ParentIndex', Tuple[int, ...])
-_T = TypeVar("_T")
+ParentIndex = NewType('ParentIndex', tuple[int, ...])
+_T = TypeVar('_T')
 
 
 def ensure_tuple_index(index: MaybeNestedIndex) -> NestedIndex:
@@ -50,12 +50,12 @@ def ensure_tuple_index(index: MaybeNestedIndex) -> NestedIndex:
     """
     if isinstance(index, (slice, int)):
         return (index,)  # single integer inserts to self
-    elif isinstance(index, tuple):
+    if isinstance(index, tuple):
         return index
 
     raise TypeError(
         trans._(
-            "Invalid nested index: {index}. Must be an int or tuple",
+            'Invalid nested index: {index}. Must be an int or tuple',
             deferred=True,
             index=index,
         )
@@ -148,9 +148,9 @@ class NestableEventedList(EventedList[_T]):
     moved (index: Index, new_index: Index, value: T)
         emitted after ``value`` is moved from ``index`` to ``new_index``
     changed (index: Index, old_value: T, value: T)
-        emitted when ``index`` is set from ``old_value`` to ``value``
+        emitted when item at ``index`` is changed from ``old_value`` to ``value``
     changed <OVERLOAD> (index: slice, old_value: list[_T], value: list[_T])
-        emitted when slice ``index`` is set from ``old_value`` to ``value``
+        emitted when slice at ``index`` is changed from ``old_value`` to ``value``
     reordered (value: self)
         emitted when the list is reordered (eg. moved/reversed).
     """
@@ -163,40 +163,46 @@ class NestableEventedList(EventedList[_T]):
     # def remove(self, value: T): ...
 
     @overload  # type: ignore
-    def __getitem__(self, key: int) -> Union[_T, NestableEventedList[_T]]:
-        ...  # pragma: no cover
+    def __getitem__(
+        self, key: int
+    ) -> Union[_T, NestableEventedList[_T]]: ...  # pragma: no cover
 
     @overload
-    def __getitem__(self, key: ParentIndex) -> NestableEventedList[_T]:
-        ...  # pragma: no cover
+    def __getitem__(
+        self, key: ParentIndex
+    ) -> NestableEventedList[_T]: ...  # pragma: no cover
 
     @overload
-    def __getitem__(self, key: slice) -> NestableEventedList[_T]:  # noqa
-        ...  # pragma: no cover
+    def __getitem__(
+        self, key: slice
+    ) -> NestableEventedList[_T]: ...  # pragma: no cover
 
     @overload
     def __getitem__(
         self, key: NestedIndex
-    ) -> Union[_T, NestableEventedList[_T]]:
-        ...  # pragma: no cover
+    ) -> Union[_T, NestableEventedList[_T]]: ...  # pragma: no cover
 
     def __getitem__(self, key: MaybeNestedIndex):
         if isinstance(key, tuple):
             item: NestableEventedList[_T] = self
             for idx in key:
-                item = item[idx]  # type: ignore
+                if not isinstance(item, MutableSequence):
+                    raise IndexError(f'index out of range: {key}')
+                item = item[idx]
             return item
         return super().__getitem__(key)
 
     @overload
-    def __setitem__(self, key: Union[int, NestedIndex], value: _T):
-        ...  # pragma: no cover
+    def __setitem__(
+        self, key: Union[int, NestedIndex], value: _T
+    ) -> None: ...  # pragma: no cover
 
     @overload
-    def __setitem__(self, key: slice, value: Iterable[_T]):
-        ...  # pragma: no cover
+    def __setitem__(
+        self, key: slice, value: Iterable[_T]
+    ) -> None: ...  # pragma: no cover
 
-    def __setitem__(self, key: MaybeNestedIndex, value):
+    def __setitem__(self, key, value):
         # NOTE: if we check isinstance(..., MutableList), then we'll actually
         # clobber object of specialized classes being inserted into the list
         # (for instance, subclasses of NestableEventedList)
@@ -224,7 +230,7 @@ class NestableEventedList(EventedList[_T]):
             return [(self[parent_i], i) for i in indices]
         return super()._delitem_indices(key)
 
-    def insert(self, index: int, value: _T):
+    def insert(self, index: int, value: _T) -> None:
         """Insert object before index."""
         # this is delicate, we want to preserve the evented list when nesting
         # but there is a high risk here of clobbering attributes of a special
@@ -233,16 +239,30 @@ class NestableEventedList(EventedList[_T]):
             value = self.__newlike__(value)
         super().insert(index, value)
 
-    def _reemit_child_event(self, event: Event):
+    def _reemit_child_event(self, event: Event) -> None:
         """An item in the list emitted an event.  Re-emit with index"""
         if hasattr(event, 'index'):
             # This event is coming from a nested List...
             # update the index as a nested index.
-            ei = (self.index(event.source),) + ensure_tuple_index(event.index)
+            ei = (self.index(event.source), *ensure_tuple_index(event.index))
             for attr in ('index', 'new_index'):
                 if hasattr(event, attr):
                     setattr(event, attr, ei)
-        super()._reemit_child_event(event)
+
+        # if the starting event was from a nestable evented list, we can
+        # use the same event type here (e.g: removed, inserted)
+        if isinstance(event.source, NestableEventedList):
+            emitter = getattr(self.events, event.type, self.events)
+        else:
+            emitter = self.events
+
+        # same as normal evented_list, but now we need to account for the
+        # potentially different emitter
+        if not hasattr(event, 'index'):
+            with contextlib.suppress(ValueError):
+                event.index = self.index(event.source)
+
+        emitter(event)
 
     def _non_negative_index(
         self, parent_index: ParentIndex, dest_index: Index
@@ -250,13 +270,12 @@ class NestableEventedList(EventedList[_T]):
         """Make sure dest_index is a positive index inside parent_index."""
         destination_group = self[parent_index]
         # not handling slice indexes
-        if isinstance(dest_index, int):
-            if dest_index < 0:
-                dest_index += len(destination_group) + 1
+        if isinstance(dest_index, int) and dest_index < 0:
+            dest_index += len(destination_group) + 1
         return dest_index
 
     def _move_plan(
-        self, sources: Iterable[NestedIndex], dest_index: NestedIndex
+        self, sources: Iterable[MaybeNestedIndex], dest_index: NestedIndex
     ) -> Generator[tuple[NestedIndex, NestedIndex], None, None]:
         """Prepared indices for a complicated nested multi-move.
 
@@ -294,9 +313,9 @@ class NestableEventedList(EventedList[_T]):
 
         dest_par, dest_i = split_nested_index(dest_index)
         if isinstance(dest_i, slice):
-            raise ValueError(
+            raise TypeError(
                 trans._(
-                    "Destination index may not be a slice",
+                    'Destination index may not be a slice',
                     deferred=True,
                 )
             )
@@ -304,15 +323,17 @@ class NestableEventedList(EventedList[_T]):
 
         # need to update indices as we pop, so we keep track of the indices
         # we have previously popped
-        popped: DefaultDict[NestedIndex, list[int]] = defaultdict(list)
+        popped: defaultdict[NestedIndex, list[int]] = defaultdict(list)
         dumped: list[int] = []
 
         # we iterate indices from the end first, so pop() always works
         for idx in sorted(sources, reverse=True):
+            if isinstance(idx, (int, slice)):
+                idx = (idx,)
             if idx == ():
                 raise IndexError(
                     trans._(
-                        "Group cannot move itself",
+                        'Group cannot move itself',
                         deferred=True,
                     )
                 )
@@ -334,9 +355,9 @@ class NestableEventedList(EventedList[_T]):
 
             src_par, src_i = split_nested_index(idx)
             if isinstance(src_i, slice):
-                raise ValueError(
+                raise TypeError(
                     trans._(
-                        "Terminal source index may not be a slice",
+                        'Terminal source index may not be a slice',
                         deferred=True,
                     )
                 )
@@ -356,7 +377,7 @@ class NestableEventedList(EventedList[_T]):
             if src_par == dest_par and src_i == dest_i - ddec:
                 continue
 
-            yield src_par + (src_i,), dest_par + (dest_i - ddec,)
+            yield (*src_par, src_i), (*dest_par, dest_i - ddec)
             popped[src_par].append(src_i)
             dumped.append(dest_i - ddec)
 
@@ -386,24 +407,28 @@ class NestableEventedList(EventedList[_T]):
             If the terminal source is a slice, or if the source is this root
             object
         """
-        logger.debug(f"move(src_index={src_index}, dest_index={dest_index})")
+        logger.debug(
+            'move(src_index=%s, dest_index=%s)',
+            src_index,
+            dest_index,
+        )
         src_par_i, src_i = split_nested_index(src_index)
         dest_par_i, dest_i = split_nested_index(dest_index)
         dest_i = self._non_negative_index(dest_par_i, dest_i)
-        dest_index = dest_par_i + (dest_i,)
+        dest_index = (*dest_par_i, dest_i)
 
         if isinstance(src_i, slice):
-            raise ValueError(
+            raise TypeError(
                 trans._(
-                    "Terminal source index may not be a slice",
+                    'Terminal source index may not be a slice',
                     deferred=True,
                 )
             )
 
         if isinstance(dest_i, slice):
-            raise ValueError(
+            raise TypeError(
                 trans._(
-                    "Destination index may not be a slice",
+                    'Destination index may not be a slice',
                     deferred=True,
                 )
             )
@@ -411,21 +436,22 @@ class NestableEventedList(EventedList[_T]):
         if src_i == ():
             raise ValueError(
                 trans._(
-                    "Group cannot move itself",
+                    'Group cannot move itself',
                     deferred=True,
                 )
             )
 
-        if src_par_i == dest_par_i:
-            if isinstance(dest_i, int):
-                if dest_i > src_i:
-                    dest_i -= 1
-                if src_i == dest_i:
-                    return False
+        if src_par_i == dest_par_i and isinstance(dest_i, int):
+            if dest_i > src_i:
+                dest_i -= 1
+            if src_i == dest_i:
+                return False
 
         self.events.moving(index=src_index, new_index=dest_index)
+
+        dest_par = self[dest_par_i]  # grab this before popping src_i
+
         with self.events.blocker_all():
-            dest_par = self[dest_par_i]  # grab this before popping src_i
             value = self[src_par_i].pop(src_i)
             dest_par.insert(dest_i, value)
 
@@ -437,8 +463,8 @@ class NestableEventedList(EventedList[_T]):
         if isinstance(e, list):
             return self.__newlike__(e)
         if self._basetypes:
-            _types = set(self._basetypes) | {NestableEventedList}
-            if not any(isinstance(e, t) for t in _types):
+            _types = self._basetypes + (NestableEventedList,)
+            if not isinstance(e, _types):
                 raise TypeError(
                     trans._(
                         'Cannot add object with type {dtype!r} to TypedList expecting type {types_!r}',
@@ -449,21 +475,30 @@ class NestableEventedList(EventedList[_T]):
                 )
         return e
 
-    def _iter_indices(self, start=0, stop=None, root=(), deep=False):
+    def _iter_indices(
+        self,
+        start: int = 0,
+        stop: Optional[int] = None,
+        root: tuple[int, ...] = (),
+    ) -> Generator[Union[int, tuple[int]]]:
         """Iter indices from start to stop.
 
         Depth first traversal of the tree
         """
-        if deep:
-            for i in range(start, len(self) if stop is None else stop):
-                if isinstance(self[i], NestableEventedList):
-                    yield from self[i]._iter_indices(  # type: ignore
-                        root=root + (i,), deep=deep
-                    )
-                else:
-                    if root:
-                        yield root + (i,)
-                    else:
-                        yield i
-        else:
-            yield from super()._iter_indices(start, stop)
+        for i, item in enumerate(self[start:stop]):
+            yield (*root, i) if root else i
+            if isinstance(item, NestableEventedList):
+                yield from item._iter_indices(root=(*root, i))
+
+    def has_index(self, index: Union[int, tuple[int, ...]]) -> bool:
+        """Return true if `index` is valid for this nestable list."""
+        if isinstance(index, int):
+            return -len(self) <= index < len(self)
+        if isinstance(index, tuple):
+            try:
+                self[index]
+            except IndexError:
+                return False
+            else:
+                return True
+        raise TypeError(f'Not supported index type {type(index)}')
