@@ -1,11 +1,17 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Iterable, Iterator, MutableSet, TypeVar
+from collections.abc import Generator, Iterable, Iterator, MutableSet, Sequence
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Optional,
+    TypeVar,
+)
 
 from napari.utils.events import EmitterGroup
 from napari.utils.translations import trans
 
-_T = TypeVar("_T")
+_T = TypeVar('_T')
 
 if TYPE_CHECKING:
     from napari._pydantic_compat import ModelField
@@ -29,13 +35,13 @@ class EventedSet(MutableSet[_T]):
     events: EmitterGroup
 
     def __init__(self, data: Iterable[_T] = ()) -> None:
-        _events = {'changed': None}
+        changed = None
         # For inheritance: If the mro already provides an EmitterGroup, add...
         if hasattr(self, 'events') and isinstance(self.events, EmitterGroup):
-            self.events.add(**_events)
+            self.events.add(changed=changed)
         else:
             # otherwise create a new one
-            self.events = EmitterGroup(source=self, **_events)
+            self.events = EmitterGroup(source=self, changed=changed)
 
         self._set: set[_T] = set()
         self.update(data)
@@ -51,11 +57,15 @@ class EventedSet(MutableSet[_T]):
     def __len__(self) -> int:
         return len(self._set)
 
-    def _pre_add_hook(self, value):
+    def _pre_add_hook(self, value: _T) -> _T:
         # for subclasses to potentially check value before adding
         return value
 
-    def _emit_change(self, added=None, removed=None):
+    def _emit_change(
+        self,
+        added: Optional[set[_T]] = None,
+        removed: Optional[set[_T]] = None,
+    ) -> None:
         # provides a hook for subclasses to update internal state before emit
         if added is None:
             added = set()
@@ -68,7 +78,7 @@ class EventedSet(MutableSet[_T]):
         if value not in self:
             value = self._pre_add_hook(value)
             self._set.add(value)
-            self._emit_change(added={value}, removed={})
+            self._emit_change(added={value}, removed=set())
 
     def discard(self, value: _T) -> None:
         """Remove an element from a set if it is a member.
@@ -77,7 +87,7 @@ class EventedSet(MutableSet[_T]):
         """
         if value in self:
             self._set.discard(value)
-            self._emit_change(added={}, removed={value})
+            self._emit_change(added=set(), removed={value})
 
     # #### END Required Abstract Methods
 
@@ -94,10 +104,10 @@ class EventedSet(MutableSet[_T]):
         if self._set:
             values = set(self)
             self._set.clear()
-            self._emit_change(added={}, removed=values)
+            self._emit_change(added=set(), removed=values)
 
     def __repr__(self) -> str:
-        return f"{type(self).__name__}({self._set!r})"
+        return f'{type(self).__name__}({self._set!r})'
 
     def update(self, others: Iterable[_T] = ()) -> None:
         """Update this set with the union of this set and others"""
@@ -105,7 +115,7 @@ class EventedSet(MutableSet[_T]):
         if to_add:
             to_add = {self._pre_add_hook(i) for i in to_add}
             self._set.update(to_add)
-            self._emit_change(added=set(to_add), removed={})
+            self._emit_change(added=set(to_add), removed=set())
 
     def copy(self) -> EventedSet[_T]:
         """Return a shallow copy of this set."""
@@ -120,7 +130,7 @@ class EventedSet(MutableSet[_T]):
         to_remove = self._set.intersection(others)
         if to_remove:
             self._set.difference_update(to_remove)
-            self._emit_change(added={}, removed=set(to_remove))
+            self._emit_change(added=set(), removed=set(to_remove))
 
     def intersection(self, others: Iterable[_T] = ()) -> EventedSet[_T]:
         """Return all elements that are in both sets as a new set."""
@@ -159,11 +169,11 @@ class EventedSet(MutableSet[_T]):
         return type(self)(self._set.union(others))
 
     @classmethod
-    def __get_validators__(cls):
+    def __get_validators__(cls) -> Generator:
         yield cls.validate
 
     @classmethod
-    def validate(cls, v, field: ModelField):
+    def validate(cls, v: Sequence, field: ModelField) -> EventedSet:
         """Pydantic validator."""
         from napari._pydantic_compat import sequence_like
 
@@ -187,9 +197,10 @@ class EventedSet(MutableSet[_T]):
         if errors:
             from napari._pydantic_compat import ValidationError
 
-            raise ValidationError(errors, cls)  # type: ignore
+            raise ValidationError(errors, cls)  # type: ignore [arg-type]
+            # need to be fixed when migrate to pydantic 2
         return cls(v)
 
-    def _json_encode(self):
+    def _json_encode(self) -> list:
         """Return an object that can be used by json.dumps."""
         return list(self)
