@@ -4,9 +4,10 @@ Our perfmon system using this to patch in perf_timers, but this can be used
 for any type of patching. See patch_callables() below as the main entrypoint.
 """
 
+import logging
 import types
 from importlib import import_module
-from typing import Callable, List, Set, Tuple, Union
+from typing import Callable, Union
 
 from napari.utils.translations import trans
 
@@ -21,13 +22,10 @@ PatchFunction = Callable[[CallableParent, str, str], None]
 class PatchError(Exception):
     """Failed to patch target, config file error?"""
 
-    def __init__(self, message) -> None:
-        self.message = message
-
 
 def _patch_attribute(
     module: types.ModuleType, attribute_str: str, patch_func: PatchFunction
-):
+) -> None:
     """Patch the module's callable pointed to by the attribute string.
 
     Parameters
@@ -45,7 +43,7 @@ def _patch_attribute(
     if attribute_str.count('.') > 1:
         raise PatchError(
             trans._(
-                "Nested attribute not found: {attribute_str}",
+                'Nested attribute not found: {attribute_str}',
                 deferred=True,
                 attribute_str=attribute_str,
             )
@@ -59,7 +57,7 @@ def _patch_attribute(
         except AttributeError as e:
             raise PatchError(
                 trans._(
-                    "Module {module_name} has no attribute {attribute_str}",
+                    'Module {module_name} has no attribute {attribute_str}',
                     deferred=True,
                     module_name=module.__name__,
                     attribute_str=attribute_str,
@@ -78,7 +76,7 @@ def _patch_attribute(
     except AttributeError as e:
         raise PatchError(
             trans._(
-                "Parent {parent_str} has no attribute {callable_str}",
+                'Parent {parent_str} has no attribute {callable_str}',
                 deferred=True,
                 parent_str=parent_str,
                 callable_str=callable_str,
@@ -86,15 +84,17 @@ def _patch_attribute(
         ) from e
 
     label = (
-        callable_str if class_str is None else f"{class_str}.{callable_str}"
+        callable_str if class_str is None else f'{class_str}.{callable_str}'
     )
 
     # Patch it with the user-provided patch_func.
-    print(f"Patcher: patching {module.__name__}.{label}")
+    logging.info('patching %s.%s', module.__name__, label)
     patch_func(parent, callable_str, label)
 
 
-def _import_module(target_str: str) -> Tuple[types.ModuleType, str]:
+def _import_module(
+    target_str: str,
+) -> Union[tuple[types.ModuleType, str], tuple[None, None]]:
     """Import the module portion of this target string.
 
     Try importing successively longer segments of the target_str. For example:
@@ -133,7 +133,7 @@ def _import_module(target_str: str) -> Tuple[types.ModuleType, str]:
                 # The very first top-level module import failed!
                 raise PatchError(
                     trans._(
-                        "Module not found: {module_path}",
+                        'Module not found: {module_path}',
                         deferred=True,
                         module_path=module_path,
                     )
@@ -142,14 +142,14 @@ def _import_module(target_str: str) -> Tuple[types.ModuleType, str]:
             # We successfully imported part of the target_str but then
             # we got a failure. Usually this is because we tried
             # importing a class or function. Return the inner-most
-            # module we did successfuly import. And return the rest of
+            # module we did successfully import. And return the rest of
             # the module_path we didn't use.
             attribute_str = '.'.join(parts[i - 1 :])
             return module, attribute_str
-    return None
+    return None, None
 
 
-def patch_callables(callables: List[str], patch_func: PatchFunction) -> None:
+def patch_callables(callables: list[str], patch_func: PatchFunction) -> None:
     """Patch the given list of callables.
 
     Parameters
@@ -179,22 +179,25 @@ def patch_callables(callables: List[str], patch_func: PatchFunction) -> None:
                 print(f"Announce {label}")
                 return wrapped(*args, **kwargs)
     """
-    patched: Set[str] = set()
+    patched: set[str] = set()
 
     for target_str in callables:
         if target_str in patched:
             # Ignore duplicated targets in the config file.
-            print(f"Patcher: [WARN] skipping duplicate {target_str}")
+            logging.warning('skipping duplicate %s', target_str)
             continue
 
         # Patch the target and note that we did.
         try:
             module, attribute_str = _import_module(target_str)
-            _patch_attribute(module, attribute_str, patch_func)
-        except PatchError as exc:
+            if module is not None and attribute_str is not None:
+                _patch_attribute(module, attribute_str, patch_func)
+        except PatchError:
             # We don't stop on error because if you switch around branches
             # but keep the same config file, it's easy for your config
             # file to contain targets that aren't in the code.
-            print(f"Patcher: [ERROR] {exc}")
+
+            # logging.exception magically logs the stack trace too!
+            logging.exception('Something went wrong while patching')
 
         patched.add(target_str)
