@@ -8,7 +8,7 @@ from napari.utils.events.containers import EventedSet
 from napari.utils.events.event import EmitterGroup, Event
 from napari.utils.translations import trans
 
-__all__ = ['progress', 'progrange', 'cancelable_progress']
+__all__ = ['cancelable_progress', 'progrange', 'progress']
 
 
 class progress(tqdm):
