@@ -9,7 +9,10 @@ _default_shortcuts = {
     'napari:toggle_ndisplay': [KeyMod.CtrlCmd | KeyCode.KeyY],
     'napari:toggle_theme': [KeyMod.CtrlCmd | KeyMod.Shift | KeyCode.KeyT],
     'napari:reset_view': [KeyMod.CtrlCmd | KeyCode.KeyR],
-    'napari:delete_selected_layers': [KeyMod.CtrlCmd | KeyCode.Delete],
+    'napari:delete_selected_layers': [
+        KeyMod.CtrlCmd | KeyCode.Delete,
+        KeyMod.CtrlCmd | KeyCode.Backspace,
+    ],
     'napari:show_shortcuts': [KeyMod.CtrlCmd | KeyMod.Alt | KeyCode.Slash],
     'napari:increment_dims_left': [KeyCode.LeftArrow],
     'napari:increment_dims_right': [KeyCode.RightArrow],
@@ -65,6 +68,7 @@ _default_shortcuts = {
     'napari:activate_add_ellipse_mode': [KeyCode.KeyE],
     'napari:activate_add_line_mode': [KeyCode.KeyL],
     'napari:activate_add_path_mode': [KeyCode.KeyT],
+    'napari:activate_add_polyline_mode': [KeyMod.Shift | KeyCode.KeyL],
     'napari:activate_add_polygon_mode': [KeyCode.KeyP],
     'napari:activate_add_polygon_lasso_mode': [KeyMod.Shift | KeyCode.KeyP],
     'napari:activate_direct_mode': [KeyCode.Digit4, KeyCode.KeyD],
