@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Generator, Iterable, List, TypeVar, Union
+from collections.abc import Generator, Iterable
+from typing import TYPE_CHECKING, TypeVar, Union
 
 from napari.utils.events.containers._selectable_list import (
     SelectableNestableEventedList,
@@ -10,7 +11,7 @@ from napari.utils.tree.node import Node
 if TYPE_CHECKING:
     from napari.utils.events.containers._nested_list import MaybeNestedIndex
 
-NodeType = TypeVar("NodeType", bound=Node)
+NodeType = TypeVar('NodeType', bound=Node)
 
 
 class Group(Node, SelectableNestableEventedList[NodeType]):
@@ -39,7 +40,7 @@ class Group(Node, SelectableNestableEventedList[NodeType]):
     def __init__(
         self,
         children: Iterable[NodeType] = (),
-        name: str = "Group",
+        name: str = 'Group',
         basetype=Node,
     ) -> None:
         Node.__init__(self, name=name)
@@ -105,16 +106,16 @@ class Group(Node, SelectableNestableEventedList[NodeType]):
         for child in obj:
             yield from child.traverse(leaves_only)
 
-    def _render(self) -> List[str]:
+    def _render(self) -> list[str]:
         """Recursively return list of strings that can render ascii tree."""
         lines = [self._node_name()]
 
         for n, child in enumerate(self):
             spacer, bul = (
-                ("   ", "└──") if n == len(self) - 1 else ("  │", "├──")
+                ('   ', '└──') if n == len(self) - 1 else ('  │', '├──')
             )
             child_tree = child._render()
-            lines.append(f"  {bul}" + child_tree.pop(0))
+            lines.append(f'  {bul}' + child_tree.pop(0))
             lines.extend([spacer + lay for lay in child_tree])
 
         return lines
