@@ -235,7 +235,7 @@ def add_comment_to_pr(
     Add a comment to an existing PR.
     """
     # Prepare the headers with the access token
-    headers = {'Authorization': f"token {os.environ.get('GITHUB_TOKEN')}"}
+    headers = {'Authorization': f'token {os.environ.get("GITHUB_TOKEN")}'}
 
     # publish the comment
     payload = {'body': message}
@@ -274,7 +274,7 @@ def update_pr(branch_name: str):
                 '\n\n This PR contains changes to the workflow file. '
             )
             comment_content += 'Please download the artifact and update the constraints files manually. '
-            comment_content += f"Artifact: https://github.com/{os.environ.get('GITHUB_REPOSITORY', 'napari/napari')}/actions/runs/{os.environ.get('GITHUB_RUN_ID')}"
+            comment_content += f'Artifact: https://github.com/{os.environ.get("GITHUB_REPOSITORY", "napari/napari")}/actions/runs/{os.environ.get("GITHUB_RUN_ID")}'
         else:
             raise
     else:
@@ -301,7 +301,7 @@ def update_external_pr_comment(
     comment += 'You could also get the updated files from the '
     comment += f'https://github.com/napari-bot/napari/tree/{new_branch_name}/resources/constraints. '
     comment += 'Or ask the maintainers to provide you the contents of the constraints artifact '
-    comment += f"from the run https://github.com/{os.environ.get('GITHUB_REPOSITORY', 'napari/napari')}/actions/runs/{os.environ.get('GITHUB_RUN_ID')}"
+    comment += f'from the run https://github.com/{os.environ.get("GITHUB_REPOSITORY", "napari/napari")}/actions/runs/{os.environ.get("GITHUB_RUN_ID")}'
     return comment
 
 
